ActionReasonCode

Enum ActionReasonCode 

pub enum ActionReasonCode {
    CareGap,
    DrugDrugInteraction,
    OffPathway,
    QualityMeasure,
    RiskAssessment,
}
ActionReasonCode. Provides examples of reasons for actions to be performed.

FHIR version: 5.0.0.

Variants



CareGap

care-gap

Care gap detected. The action should be performed to address a detected care gap.



DrugDrugInteraction

drug-drug-interaction

Drug-drug interaction. The action should be performed to address a detected potential drug-drug interaction.



OffPathway

off-pathway

Off pathway. The action should be performed because the patient was determined to be off pathway.



QualityMeasure

quality-measure

Quality measure. The action should be performed to bring the patient’s care in line with a quality measure.



RiskAssessment

risk-assessment

Risk assessment. The action should be performed based on a particular risk assessment.