ActionSelectionBehavior

Enum ActionSelectionBehavior 

pub enum ActionSelectionBehavior {
    All,
    AllOrNone,
    Any,
    AtMostOne,
    ExactlyOne,
    OneOrMore,
}
ActionSelectionBehavior. Defines selection behavior of a group.

FHIR version: 5.0.0.

Variants



All

all

All. All the actions in the group must be selected as a single unit.



AllOrNone

all-or-none

All Or None. All the actions in the group are meant to be chosen as a single unit: either all must be selected by the end user, or none may be selected.



Any

any

Any. Any number of the actions in the group may be chosen, from zero to all.



AtMostOne

at-most-one

At Most One. The end user may choose zero or at most one of the actions in the group.



ExactlyOne

exactly-one

Exactly One. The end user must choose one and only one of the selectable actions in the group. The user SHALL NOT choose none of the actions in the group.



OneOrMore

one-or-more

One Or More. The end user must choose a minimum of one, and as many additional as desired.