pub enum AggregationMode {
Bundled,
Contained,
Referenced,
}Expand description
AggregationMode. How resource references can be aggregated.
FHIR version: 5.0.0.
Variants
Bundled
bundled
Bundled. When the resource is in a Bundle, the resource the reference points to will be found in the same bundle as the resource that includes the reference.
Contained
contained
Contained. The reference is a local reference to a contained resource.
Referenced
referenced
Referenced. The reference to a resource that has to be resolved externally to the resource that includes the reference.