BundleType

Enum BundleType 

pub enum BundleType {
    Batch,
    BatchResponse,
    Collection,
    Document,
    History,
    Message,
    Searchset,
    SubscriptionNotification,
    Transaction,
    TransactionResponse,
}
BundleType. Indicates the purpose of a bundle - how it is intended to be used.

FHIR version: 5.0.0.

Variants



Batch

batch

Batch. The bundle is a set of actions - intended to be processed by a server as a group of independent actions.



BatchResponse

batch-response

Batch Response. The bundle is a batch response. Note that as a batch, some responses may indicate failure and others success.



Collection

collection

Collection. The bundle is a set of resources collected into a single package for ease of distribution that imposes no processing obligations or behavioral rules beyond persistence.



Document

document

Document. The bundle is a document. The first resource is a Composition.



History

history

History List. The bundle is a list of resources from a history interaction on a server.



Message

message

Message. The bundle is a message. The first resource is a MessageHeader.



Searchset

searchset

Search Results. The bundle is a list of resources returned as a result of a search/query interaction, operation, or message.



SubscriptionNotification

subscription-notification

Subscription Notification. The bundle has been generated by a Subscription to communicate information to a client.



Transaction

transaction

Transaction. The bundle is a transaction - intended to be processed by a server as an atomic commit.



TransactionResponse

transaction-response

Transaction Response. The bundle is a transaction response. Because the response is a transaction response, the transaction has succeeded, and all responses are error free.