pub enum CapabilityStatementKind {
Capability,
Instance,
Requirements,
}Expand description
CapabilityStatementKind. How a capability statement is intended to be used.
FHIR version: 5.0.0.
Variants
Capability
capability
Capability. The CapabilityStatement instance represents the capabilities of a system or piece of software, independent of a particular installation.
Instance
instance
Instance. The CapabilityStatement instance represents the present capabilities of a specific system instance. This is the kind returned by /metadata for a FHIR server end-point.
Requirements
requirements
Requirements. The CapabilityStatement instance represents a set of requirements for other systems to meet; e.g. as part of an implementation guide or ‘request for proposal’.