CitationClassificationType

Enum CitationClassificationType 

pub enum CitationClassificationType {
    CitationSource,
    FevirPlatformUse,
    MedlineOwner,
}
CitationClassificationType. Citation classification type

FHIR version: 5.0.0.

Variants



CitationSource

citation-source

Citation Source. Citation repository where this citation was created or copied from



FevirPlatformUse

fevir-platform-use

FEvIR Platform Use. Used for Citation sharing on the Fast Evidence Interoperability Resources (FEvIR) Platform



MedlineOwner

medline-owner

MEDLINE Citation Owner. The party responsible for creating and validating the MEDLINE citation