CompositionStatus

Enum CompositionStatus 

pub enum CompositionStatus {
    Amended,
    Appended,
    Cancelled,
    Corrected,
    Deprecated,
    EnteredInError,
    Final,
    Partial,
    Preliminary,
    Registered,
    Unknown,
}
CompositionStatus. The workflow/clinical status of the composition.

FHIR version: 5.0.0.

Variants



Amended

amended

Amended. The composition content or the referenced resources have been modified (edited or added to) subsequent to being released as “final” and the composition is complete and verified by an authorized person.



Appended

appended

Appended. Subsequent to being final, the composition content has been modified by adding new content. The existing content is unchanged.



Cancelled

cancelled

Cancelled. The composition is unavailable because the measurement was not started or not completed (also sometimes called “aborted”).



Corrected

corrected

Corrected. Subsequent to being final, the composition content has been modified to correct an error in the composition or referenced results.



Deprecated

deprecated

Deprecated. This composition has been withdrawn or superseded and should no longer be used.



EnteredInError

entered-in-error

Entered in Error. The composition or document was originally created/issued in error, and this is an amendment that marks that the entire series should not be considered as valid.



Final

final

Final. This version of the composition is complete and verified by an appropriate person and no further work is planned. Any subsequent updates would be on a new version of the composition.



Partial

partial

Partial. This is a partial (e.g. initial, interim or preliminary) composition: data in the composition may be incomplete or unverified.



Preliminary

preliminary

Preliminary. Verified early results are available, but not all results are final.



Registered

registered

Registered. The existence of the composition is registered, but there is nothing yet available.



Unknown

unknown

Unknown. The authoring/source system does not know which of the status values currently applies for this observation. Note: This concept is not to be used for “other” - one of the listed statuses is presumed to apply, but the authoring/source system does not know which.