pub enum ConceptMapAttributeType {
Coding,
Quantity,
Boolean,
Code,
String,
}Expand description
ConceptMapAttributeType. The type of a ConceptMap map attribute value.
FHIR version: 5.0.0.
Variants
Coding
Coding
Coding. The attribute value is a code defined in a code system.
Quantity
Quantity
Quantity. The attribute is a Quantity (may represent an integer or a decimal with no units).
Boolean
boolean
boolean. The attribute value is a boolean true | false.
Code
code
code. The attribute value is a code defined in the code system in context.
String
string
string. The attribute value is a string.