pub enum ConceptMapPropertyType {
Coding,
Boolean,
Code,
DateTime,
Decimal,
Integer,
String,
}Expand description
ConceptMapPropertyType. The type of a ConceptMap mapping property value.
FHIR version: 5.0.0.
Variants
Coding
Coding
Coding (external reference). The property value is a code defined in an external code system. This may be used for translations, but is not the intent.
Boolean
boolean
boolean. The property value is a boolean true | false.
Code
code
code. The property value is a code as defined in the CodeSystem in ConceptMap.property.system.
DateTime
dateTime
dateTime. The property is a date or a date + time.
Decimal
decimal
decimal. The property value is a decimal number.
Integer
integer
integer. The property value is an integer (often used to assign ranking values to concepts for supporting score assessments).
String
string
string. The property value is a string.