ConditionalDeleteStatus

Enum ConditionalDeleteStatus 

pub enum ConditionalDeleteStatus {
    Multiple,
    NotSupported,
    Single,
}
ConditionalDeleteStatus. A code that indicates how the server supports conditional delete.

FHIR version: 5.0.0.

Variants



Multiple

multiple

Multiple Deletes Supported. Conditional deletes are supported, and multiple resources can be deleted in a single interaction.



NotSupported

not-supported

Not Supported. No support for conditional deletes.



Single

single

Single Deletes Supported. Conditional deletes are supported, but only single resources at a time.