ConditionalReadStatus

Enum ConditionalReadStatus 

pub enum ConditionalReadStatus {
    FullSupport,
    ModifiedSince,
    NotMatch,
    NotSupported,
}
ConditionalReadStatus. A code that indicates how the server supports conditional read.

FHIR version: 5.0.0.

Variants



FullSupport

full-support

Full Support. Conditional reads are supported, with both If-Modified-Since and If-None-Match HTTP Headers.



ModifiedSince

modified-since

If-Modified-Since. Conditional reads are supported, but only with the If-Modified-Since HTTP Header.



NotMatch

not-match

If-None-Match. Conditional reads are supported, but only with the If-None-Match HTTP Header.



NotSupported

not-supported

Not Supported. No support for conditional reads.