pub enum ContactPointUse {
Home,
Mobile,
Old,
Temp,
Work,
}Expand description
ContactPointUse. Use of contact point.
FHIR version: 5.0.0.
Variants
Home
home
Home. A communication contact point at a home; attempted contacts for business purposes might intrude privacy and chances are one will contact family or other household members instead of the person one wishes to call. Typically used with urgent cases, or if no other contacts are available.
Mobile
mobile
Mobile. A telecommunication device that moves and stays with its owner. May have characteristics of all other use codes, suitable for urgent matters, not the first choice for routine business.
Old
old
Old. This contact point is no longer in use (or was never correct, but retained for records).
Temp
temp
Temp. A temporary contact point. The period can provide more detailed information.
Work
work
Work. An office contact point. First choice for business related contacts during business hours.