DeviceDispenseStatusCodes

Enum DeviceDispenseStatusCodes 

pub enum DeviceDispenseStatusCodes {
    Cancelled,
    Completed,
    Declined,
    EnteredInError,
    InProgress,
    OnHold,
    Preparation,
    Stopped,
    Unknown,
}
DeviceDispenseStatusCodes. DeviceDispense Status Codes

FHIR version: 5.0.0.

Variants



Cancelled

cancelled

Cancelled. The dispensed product was not and will never be picked up by the patient.



Completed

completed

Completed. The dispensed product has been picked up.



Declined

declined

Declined. The dispense was declined and not performed.



EnteredInError

entered-in-error

Entered in Error. The dispense was entered in error and therefore nullified.



InProgress

in-progress

In Progress. The dispensed product is ready for pickup.



OnHold

on-hold

On Hold. The dispense process is paused while waiting for an external event to reactivate the dispense. For example, new stock has arrived or the prescriber has called.



Preparation

preparation

Preparation. The core event has not started yet, but some staging activities have begun (e.g. initial preparing of the device. Preparation stages may be tracked e.g. for planning, supply or billing purposes.



Stopped

stopped

Stopped. Actions implied by the dispense have been permanently halted, before all of them occurred.



Unknown

unknown

Unknown. The authoring system does not know which of the status values applies for this dispense. Note: this concept is not to be used for other - one of the listed statuses is presumed to apply, it’s just now known which one.