DeviceUsageStatus

Enum DeviceUsageStatus 

pub enum DeviceUsageStatus {
    Active,
    Completed,
    EnteredInError,
    Intended,
    NotDone,
    OnHold,
    Stopped,
}
DeviceUsageStatus. A coded concept indicating the current status of the Device Usage.

FHIR version: 5.0.0.

Variants



Active

active

Active. The device is still being used.



Completed

completed

Completed. The device is no longer being used.



EnteredInError

entered-in-error

Entered in Error. The statement was recorded incorrectly.



Intended

intended

Intended. The device may be used at some time in the future.



NotDone

not-done

Not done. The device was not used.



OnHold

on-hold

On Hold. Actions implied by the statement have been temporarily halted, but are expected to continue later. May also be called “suspended”.



Stopped

stopped

Stopped. Actions implied by the statement have been permanently halted, before all of them occurred.