pub enum EventTiming {
Show 14 variants
Aft,
AftEarly,
AftLate,
Eve,
EveEarly,
EveLate,
Imd,
Morn,
MornEarly,
MornLate,
Night,
Noon,
Phs,
_Custom(String),
}Expand description
EventTiming. Real-world event relating to the schedule.
FHIR version: 5.0.0.
Variants
Aft
AFT
Afternoon. Event occurs during the afternoon. The exact time is unspecified and established by institution convention or patient interpretation.
AftEarly
AFT.early
Early Afternoon. Event occurs during the early afternoon. The exact time is unspecified and established by institution convention or patient interpretation.
AftLate
AFT.late
Late Afternoon. Event occurs during the late afternoon. The exact time is unspecified and established by institution convention or patient interpretation.
Eve
EVE
Evening. Event occurs during the evening. The exact time is unspecified and established by institution convention or patient interpretation.
EveEarly
EVE.early
Early Evening. Event occurs during the early evening. The exact time is unspecified and established by institution convention or patient interpretation.
EveLate
EVE.late
Late Evening. Event occurs during the late evening. The exact time is unspecified and established by institution convention or patient interpretation.
Imd
IMD
Immediate. Event occurs a single time (with no repetitions) as soon as possible after the scheduled or actual start of the overall event.
Morn
MORN
Morning. Event occurs during the morning. The exact time is unspecified and established by institution convention or patient interpretation.
MornEarly
MORN.early
Early Morning. Event occurs during the early morning. The exact time is unspecified and established by institution convention or patient interpretation.
MornLate
MORN.late
Late Morning. Event occurs during the late morning. The exact time is unspecified and established by institution convention or patient interpretation.
Night
NIGHT
Night. Event occurs during the night. The exact time is unspecified and established by institution convention or patient interpretation.
Noon
NOON
Noon. Event occurs around 12:00pm. The exact time is unspecified and established by institution convention or patient interpretation.
Phs
PHS
After Sleep. Event occurs [offset] after subject goes to sleep. The exact time is unspecified and established by institution convention or patient interpretation.
_Custom(String)
Custom code value.