EvidenceClassifier

Enum EvidenceClassifier 

pub enum EvidenceClassifier {
Show 31 variants AllocConcealNotStated, BaselineImbalance, Covid19HumanResearch, Covid19Relevant, Covid19Specific, Diagnosis, EarlyTrialTermination, Guideline, NoBlinding, NoItt, NotAssessed, NotResearchNotGuideline, OriginalResearch, PreliminaryAnalysis, Preprint, PreventionAndControl, PrognosisPrediction, RatedAsCaseControl, RatedAsComparativeCohort, RatedAsControlledTrial, RatedAsMixedMethods, RatedAsNo, RatedAsOther, RatedAsRct, RatedAsUncontrolledSeries, RatedAsYes, ResearchProtocol, ResearchSynthesis, RiskOfBias, SubgroupAnalysis, Treatment,
}
EvidenceClassifier. Commonly used classifiers for evidence sets.

FHIR version: 5.0.0.

Variants



AllocConcealNotStated

AllocConcealNotStated

Allocation concealment not stated. Allocation concealment not stated.



BaselineImbalance

BaselineImbalance

Baseline imbalances. Differences between groups at start of trial may confound or bias the findings.



Covid19HumanResearch

COVID19HumanResearch

COVID-19 human data in population, exposure, or outcome. contains human COVID-19 disease in the research data as any variable (population, exposure or outcome).



Covid19Relevant

COVID19Relevant

COVID-19 relevant (but not specific) article. Not about COVID-19 but relevant to COVID-19 management or understanding.



Covid19Specific

COVID19Specific

COVID-19 specific article. About COVID-19.



Diagnosis

Diagnosis

Article about diagnosis. about methods to distinguish having or not having a condition.



EarlyTrialTermination

EarlyTrialTermination

Early trial termination. Early trial termination.



Guideline

Guideline

Article includes guideline. for clinical practice guidelines.



NoBlinding

NoBlinding

No blinding. No blinding.



NoItt

NoITT

No intention-to-treat analysis. No intention-to-treat analysis.



NotAssessed

NotAssessed

Not rated, not assessed. Neither rated as yes nor rated as no.



NotResearchNotGuideline

NotResearchNotGuideline

Article is neither research nor guideline. for things that are not research reports, research protocols or guidelines.



OriginalResearch

OriginalResearch

Article includes original research. such as randomized trial, observational study.



PreliminaryAnalysis

PreliminaryAnalysis

Preliminary analysis. Preliminary analysis.



Preprint

Preprint

Preprint (not final publication). Results presented in preprint (pre-final publication) form.



PreventionAndControl

PreventionAndControl

Article about prevention and control. about preventive care and interventions.



PrognosisPrediction

PrognosisPrediction

Article about prognosis or prediction. about predicting risk for something or risk factors for it.



RatedAsCaseControl

RatedAsCaseControl

classified as case-control study. classified as case-control study.



RatedAsComparativeCohort

RatedAsComparativeCohort

classified as comparative cohort study (observational). classified as comparative cohort study (observational).



RatedAsControlledTrial

RatedAsControlledTrial

classified as nonrandomized controlled trial (experimental). classified as nonrandomized controlled trial (experimental).



RatedAsMixedMethods

RatedAsMixedMethods

classified as mixed-methods study. classified as mixed-methods study.



RatedAsNo

RatedAsNo

Rated as no, negative, absent, or exclude. Rated as no, negative, absent, or exclude.



RatedAsOther

RatedAsOther

classified as other concept (not elsewhere classified). classified as other concept (not elsewhere classified).



RatedAsRct

RatedAsRCT

classified as randomized controlled trial. classified as randomized controlled trial.



RatedAsUncontrolledSeries

RatedAsUncontrolledSeries

classified as uncontrolled cohort (case series). classified as uncontrolled cohort (case series).



RatedAsYes

RatedAsYes

Rated as yes, affirmative, positive, present, or include.



ResearchProtocol

ResearchProtocol

Article provides protocol without results. for research protocols.



ResearchSynthesis

ResearchSynthesis

Article includes synthesis of research. such as systematic review, meta-analysis, rapid review.



RiskOfBias

RiskOfBias

Risk of bias assessment. Risk of bias assessment.



SubgroupAnalysis

SubgroupAnalysis

Subgroup analysis. Subgroup analysis.



Treatment

Treatment

Article about treatment. about therapeutic interventions.