FHIRTypes

Enum FHIRTypes 

pub enum FHIRTypes {
Show 231 variants Account, ActivityDefinition, ActorDefinition, Address, AdministrableProductDefinition, AdverseEvent, Age, AllergyIntolerance, Annotation, Appointment, AppointmentResponse, ArtifactAssessment, Attachment, AuditEvent, Availability, BackboneElement, BackboneType, Base, Basic, Binary, BiologicallyDerivedProduct, BiologicallyDerivedProductDispense, BodyStructure, Bundle, CanonicalResource, CapabilityStatement, CarePlan, CareTeam, ChargeItem, ChargeItemDefinition, Citation, Claim, ClaimResponse, ClinicalImpression, ClinicalUseDefinition, CodeSystem, CodeableConcept, CodeableReference, Coding, Communication, CommunicationRequest, CompartmentDefinition, Composition, ConceptMap, Condition, ConditionDefinition, Consent, ContactDetail, ContactPoint, Contract, Contributor, Count, Coverage, CoverageEligibilityRequest, CoverageEligibilityResponse, DataRequirement, DataType, DetectedIssue, Device, DeviceAssociation, DeviceDefinition, DeviceDispense, DeviceMetric, DeviceRequest, DeviceUsage, DiagnosticReport, Distance, DocumentReference, DomainResource, Dosage, Duration, Element, ElementDefinition, Encounter, EncounterHistory, Endpoint, EnrollmentRequest, EnrollmentResponse, EpisodeOfCare, EventDefinition, Evidence, EvidenceReport, EvidenceVariable, ExampleScenario, ExplanationOfBenefit, Expression, ExtendedContactDetail, Extension, FamilyMemberHistory, Flag, FormularyItem, GenomicStudy, Goal, GraphDefinition, Group, GuidanceResponse, HealthcareService, HumanName, Identifier, ImagingSelection, ImagingStudy, Immunization, ImmunizationEvaluation, ImmunizationRecommendation, ImplementationGuide, Ingredient, InsurancePlan, InventoryItem, InventoryReport, Invoice, Library, Linkage, List, Location, ManufacturedItemDefinition, MarketingStatus, Measure, MeasureReport, Medication, MedicationAdministration, MedicationDispense, MedicationKnowledge, MedicationRequest, MedicationStatement, MedicinalProductDefinition, MessageDefinition, MessageHeader, Meta, MetadataResource, MolecularSequence, MonetaryComponent, Money, NamingSystem, Narrative, NutritionIntake, NutritionOrder, NutritionProduct, Observation, ObservationDefinition, OperationDefinition, OperationOutcome, Organization, OrganizationAffiliation, PackagedProductDefinition, ParameterDefinition, Parameters, Patient, PaymentNotice, PaymentReconciliation, Period, Permission, Person, PlanDefinition, Practitioner, PractitionerRole, PrimitiveType, Procedure, ProductShelfLife, Provenance, Quantity, Questionnaire, QuestionnaireResponse, Range, Ratio, RatioRange, Reference, RegulatedAuthorization, RelatedArtifact, RelatedPerson, RequestOrchestration, Requirements, ResearchStudy, ResearchSubject, Resource, RiskAssessment, SampledData, Schedule, SearchParameter, ServiceRequest, Signature, Slot, Specimen, SpecimenDefinition, StructureDefinition, StructureMap, Subscription, SubscriptionStatus, SubscriptionTopic, Substance, SubstanceDefinition, SubstanceNucleicAcid, SubstancePolymer, SubstanceProtein, SubstanceReferenceInformation, SubstanceSourceMaterial, SupplyDelivery, SupplyRequest, Task, TerminologyCapabilities, TestPlan, TestReport, TestScript, Timing, Transport, TriggerDefinition, UsageContext, ValueSet, VerificationResult, VirtualServiceDetail, VisionPrescription, Base64Binary, Boolean, Canonical, Code, Date, DateTime, Decimal, Id, Instant, Integer, Integer64, Markdown, Oid, PositiveInt, String, Time, UnsignedInt, Uri, Url, Uuid, Xhtml,
}
FHIRTypes. One of the types defined as part of this version of FHIR.

FHIR version: 5.0.0.

Variants



Account

Account

Account. A financial tool for tracking value accrued for a particular purpose. In the healthcare field, used to track charges for a patient, cost centers, etc.



ActivityDefinition

ActivityDefinition

ActivityDefinition. This resource allows for the definition of some activity to be performed, independent of a particular patient, practitioner, or other performance context.



ActorDefinition

ActorDefinition

ActorDefinition. The ActorDefinition resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.



Address

Address

Address. Address Type: An address expressed using postal conventions (as opposed to GPS or other location definition formats). This data type may be used to convey addresses for use in delivering mail as well as for visiting locations which might not be valid for mail delivery. There are a variety of postal address formats defined around the world. The ISO21090-codedString may be used to provide a coded representation of the contents of strings in an Address.



AdministrableProductDefinition

AdministrableProductDefinition

AdministrableProductDefinition. A medicinal product in the final form which is suitable for administering to a patient (after any mixing of multiple components, dissolution etc. has been performed).



AdverseEvent

AdverseEvent

AdverseEvent. An event (i.e. any change to current patient status) that may be related to unintended effects on a patient or research participant. The unintended effects may require additional monitoring, treatment, hospitalization, or may result in death. The AdverseEvent resource also extends to potential or avoided events that could have had such effects. There are two major domains where the AdverseEvent resource is expected to be used. One is in clinical care reported adverse events and the other is in reporting adverse events in clinical research trial management. Adverse events can be reported by healthcare providers, patients, caregivers or by medical products manufacturers. Given the differences between these two concepts, we recommend consulting the domain specific implementation guides when implementing the AdverseEvent Resource. The implementation guides include specific extensions, value sets and constraints.



Age

Age

Age. Age Type: A duration of time during which an organism (or a process) has existed.



AllergyIntolerance

AllergyIntolerance

AllergyIntolerance. Risk of harmful or undesirable, physiological response which is unique to an individual and associated with exposure to a substance.



Annotation

Annotation

Annotation. Annotation Type: A text note which also contains information about who made the statement and when.



Appointment

Appointment

Appointment. A booking of a healthcare event among patient(s), practitioner(s), related person(s) and/or device(s) for a specific date/time. This may result in one or more Encounter(s).



AppointmentResponse

AppointmentResponse

AppointmentResponse. A reply to an appointment request for a patient and/or practitioner(s), such as a confirmation or rejection.



ArtifactAssessment

ArtifactAssessment

ArtifactAssessment. This Resource provides one or more comments, classifiers or ratings about a Resource and supports attribution and rights management metadata for the added content.



Attachment

Attachment

Attachment. Attachment Type: For referring to data content defined in other formats.



AuditEvent

AuditEvent

AuditEvent. A record of an event relevant for purposes such as operations, privacy, security, maintenance, and performance analysis.



Availability

Availability

Availability. Availability Type: Availability data for an {item}.



BackboneElement

BackboneElement

BackboneElement. BackboneElement Type: Base definition for all elements that are defined inside a resource - but not those in a data type.



BackboneType

BackboneType

BackboneType. BackboneType Type: Base definition for the few data types that are allowed to carry modifier extensions.



Base

Base

Base. Base Type: Base definition for all types defined in FHIR type system.



Basic

Basic

Basic. Basic is used for handling concepts not yet defined in FHIR, narrative-only resources that don’t map to an existing resource, and custom resources not appropriate for inclusion in the FHIR specification.



Binary

Binary

Binary. A resource that represents the data of a single raw artifact as digital content accessible in its native format. A Binary resource can contain any content, whether text, image, pdf, zip archive, etc.



BiologicallyDerivedProduct

BiologicallyDerivedProduct

BiologicallyDerivedProduct. A biological material originating from a biological entity intended to be transplanted or infused into another (possibly the same) biological entity.



BiologicallyDerivedProductDispense

BiologicallyDerivedProductDispense

BiologicallyDerivedProductDispense. A record of dispensation of a biologically derived product.



BodyStructure

BodyStructure

BodyStructure. Record details about an anatomical structure. This resource may be used when a coded concept does not provide the necessary detail needed for the use case.



Bundle

Bundle

Bundle. A container for a collection of resources.



CanonicalResource

CanonicalResource

CanonicalResource. Common Interface declaration for conformance and knowledge artifact resources.



CapabilityStatement

CapabilityStatement

CapabilityStatement. A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server or Client for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.



CarePlan

CarePlan

CarePlan. Describes the intention of how one or more practitioners intend to deliver care for a particular patient, group or community for a period of time, possibly limited to care for a specific condition or set of conditions.



CareTeam

CareTeam

CareTeam. The Care Team includes all the people and organizations who plan to participate in the coordination and delivery of care.



ChargeItem

ChargeItem

ChargeItem. The resource ChargeItem describes the provision of healthcare provider products for a certain patient, therefore referring not only to the product, but containing in addition details of the provision, like date, time, amounts and participating organizations and persons. Main Usage of the ChargeItem is to enable the billing process and internal cost allocation.



ChargeItemDefinition

ChargeItemDefinition

ChargeItemDefinition. The ChargeItemDefinition resource provides the properties that apply to the (billing) codes necessary to calculate costs and prices. The properties may differ largely depending on type and realm, therefore this resource gives only a rough structure and requires profiling for each type of billing code system.



Citation

Citation

Citation. The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources.



Claim

Claim

Claim. A provider issued list of professional services and products which have been provided, or are to be provided, to a patient which is sent to an insurer for reimbursement.



ClaimResponse

ClaimResponse

ClaimResponse. This resource provides the adjudication details from the processing of a Claim resource.



ClinicalImpression

ClinicalImpression

ClinicalImpression. A record of a clinical assessment performed to determine what problem(s) may affect the patient and before planning the treatments or management strategies that are best to manage a patient’s condition. Assessments are often 1:1 with a clinical consultation / encounter, but this varies greatly depending on the clinical workflow. This resource is called “ClinicalImpression” rather than “ClinicalAssessment” to avoid confusion with the recording of assessment tools such as Apgar score.



ClinicalUseDefinition

ClinicalUseDefinition

ClinicalUseDefinition. A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.



CodeSystem

CodeSystem

CodeSystem. The CodeSystem resource is used to declare the existence of and describe a code system or code system supplement and its key properties, and optionally define a part or all of its content.



CodeableConcept

CodeableConcept

CodeableConcept. CodeableConcept Type: A concept that may be defined by a formal reference to a terminology or ontology or may be provided by text.



CodeableReference

CodeableReference

CodeableReference. CodeableReference Type: A reference to a resource (by instance), or instead, a reference to a concept defined in a terminology or ontology (by class).



Coding

Coding

Coding. Coding Type: A reference to a code defined by a terminology system.



Communication

Communication

Communication. A clinical or business level record of information being transmitted or shared; e.g. an alert that was sent to a responsible provider, a public health agency communication to a provider/reporter in response to a case report for a reportable condition.



CommunicationRequest

CommunicationRequest

CommunicationRequest. A request to convey information; e.g. the CDS system proposes that an alert be sent to a responsible provider, the CDS system proposes that the public health agency be notified about a reportable condition.



CompartmentDefinition

CompartmentDefinition

CompartmentDefinition. A compartment definition that defines how resources are accessed on a server.



Composition

Composition

Composition. A set of healthcare-related information that is assembled together into a single logical package that provides a single coherent statement of meaning, establishes its own context and that has clinical attestation with regard to who is making the statement. A Composition defines the structure and narrative content necessary for a document. However, a Composition alone does not constitute a document. Rather, the Composition must be the first entry in a Bundle where Bundle.type=document, and any other resources referenced from Composition must be included as subsequent entries in the Bundle (for example Patient, Practitioner, Encounter, etc.).



ConceptMap

ConceptMap

ConceptMap. A statement of relationships from one set of concepts to one or more other concepts - either concepts in code systems, or data element/data element concepts, or classes in class models.



Condition

Condition

Condition. A clinical condition, problem, diagnosis, or other event, situation, issue, or clinical concept that has risen to a level of concern.



ConditionDefinition

ConditionDefinition

ConditionDefinition. A definition of a condition and information relevant to managing it.



Consent

Consent

Consent. A record of a healthcare consumer’s choices or choices made on their behalf by a third party, which permits or denies identified recipient(s) or recipient role(s) to perform one or more actions within a given policy context, for specific purposes and periods of time.



ContactDetail

ContactDetail

ContactDetail. ContactDetail Type: Specifies contact information for a person or organization.



ContactPoint

ContactPoint

ContactPoint. ContactPoint Type: Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.



Contract

Contract

Contract. Legally enforceable, formally recorded unilateral or bilateral directive i.e., a policy or agreement.



Contributor

Contributor

Contributor. Contributor Type: A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers.



Count

Count

Count. Count Type: A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.



Coverage

Coverage

Coverage. Financial instrument which may be used to reimburse or pay for health care products and services. Includes both insurance and self-payment.



CoverageEligibilityRequest

CoverageEligibilityRequest

CoverageEligibilityRequest. The CoverageEligibilityRequest provides patient and insurance coverage information to an insurer for them to respond, in the form of an CoverageEligibilityResponse, with information regarding whether the stated coverage is valid and in-force and optionally to provide the insurance details of the policy.



CoverageEligibilityResponse

CoverageEligibilityResponse

CoverageEligibilityResponse. This resource provides eligibility and plan details from the processing of an CoverageEligibilityRequest resource.



DataRequirement

DataRequirement

DataRequirement. DataRequirement Type: Describes a required data item for evaluation in terms of the type of data, and optional code or date-based filters of the data.



DataType

DataType

DataType. DataType Type: The base class for all re-useable types defined as part of the FHIR Specification.



DetectedIssue

DetectedIssue

DetectedIssue. Indicates an actual or potential clinical issue with or between one or more active or proposed clinical actions for a patient; e.g. Drug-drug interaction, Ineffective treatment frequency, Procedure-condition conflict, gaps in care, etc.



Device

Device

Device. This resource describes the properties (regulated, has real time clock, etc.), adminstrative (manufacturer name, model number, serial number, firmware, etc.), and type (knee replacement, blood pressure cuff, MRI, etc.) of a physical unit (these values do not change much within a given module, for example the serail number, manufacturer name, and model number). An actual unit may consist of several modules in a distinct hierarchy and these are represented by multiple Device resources and bound through the ‘parent’ element.



DeviceAssociation

DeviceAssociation

DeviceAssociation. A record of association of a device.



DeviceDefinition

DeviceDefinition

DeviceDefinition. This is a specialized resource that defines the characteristics and capabilities of a device.



DeviceDispense

DeviceDispense

DeviceDispense. Indicates that a device is to be or has been dispensed for a named person/patient. This includes a description of the product (supply) provided and the instructions for using the device.



DeviceMetric

DeviceMetric

DeviceMetric. Describes a measurement, calculation or setting capability of a device. The DeviceMetric resource is derived from the ISO/IEEE 11073-10201 Domain Information Model standard, but is more widely applicable.



DeviceRequest

DeviceRequest

DeviceRequest. Represents a request a device to be provided to a specific patient. The device may be an implantable device to be subsequently implanted, or an external assistive device, such as a walker, to be delivered and subsequently be used.



DeviceUsage

DeviceUsage

DeviceUsage. A record of a device being used by a patient where the record is the result of a report from the patient or a clinician.



DiagnosticReport

DiagnosticReport

DiagnosticReport. The findings and interpretation of diagnostic tests performed on patients, groups of patients, products, substances, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. The report also includes non-clinical context such as batch analysis and stability reporting of products and substances.



Distance

Distance

Distance. Distance Type: A length - a value with a unit that is a physical distance.



DocumentReference

DocumentReference

DocumentReference. A reference to a document of any kind for any purpose. While the term “document” implies a more narrow focus, for this resource this “document” encompasses any serialized object with a mime-type, it includes formal patient-centric documents (CDA), clinical notes, scanned paper, non-patient specific documents like policy text, as well as a photo, video, or audio recording acquired or used in healthcare. The DocumentReference resource provides metadata about the document so that the document can be discovered and managed. The actual content may be inline base64 encoded data or provided by direct reference.



DomainResource

DomainResource

DomainResource. A resource that includes narrative, extensions, and contained resources.



Dosage

Dosage

Dosage. Dosage Type: Indicates how the medication is/was taken or should be taken by the patient.



Duration

Duration

Duration. Duration Type: A length of time.



Element

Element

Element. Element Type: Base definition for all elements in a resource.



ElementDefinition

ElementDefinition

ElementDefinition. ElementDefinition Type: Captures constraints on each element within the resource, profile, or extension.



Encounter

Encounter

Encounter. An interaction between healthcare provider(s), and/or patient(s) for the purpose of providing healthcare service(s) or assessing the health status of patient(s).



EncounterHistory

EncounterHistory

EncounterHistory. A record of significant events/milestones key data throughout the history of an Encounter



Endpoint

Endpoint

Endpoint. The technical details of an endpoint that can be used for electronic services, such as for web services providing XDS.b, a REST endpoint for another FHIR server, or a s/Mime email address. This may include any security context information.



EnrollmentRequest

EnrollmentRequest

EnrollmentRequest. This resource provides the insurance enrollment details to the insurer regarding a specified coverage.



EnrollmentResponse

EnrollmentResponse

EnrollmentResponse. This resource provides enrollment and plan details from the processing of an EnrollmentRequest resource.



EpisodeOfCare

EpisodeOfCare

EpisodeOfCare. An association between a patient and an organization / healthcare provider(s) during which time encounters may occur. The managing organization assumes a level of responsibility for the patient during this time.



EventDefinition

EventDefinition

EventDefinition. The EventDefinition resource provides a reusable description of when a particular event can occur.



Evidence

Evidence

Evidence. The Evidence Resource provides a machine-interpretable expression of an evidence concept including the evidence variables (e.g., population, exposures/interventions, comparators, outcomes, measured variables, confounding variables), the statistics, and the certainty of this evidence.



EvidenceReport

EvidenceReport

EvidenceReport. The EvidenceReport Resource is a specialized container for a collection of resources and codeable concepts, adapted to support compositions of Evidence, EvidenceVariable, and Citation resources and related concepts.



EvidenceVariable

EvidenceVariable

EvidenceVariable. The EvidenceVariable resource describes an element that knowledge (Evidence) is about.



ExampleScenario

ExampleScenario

ExampleScenario. A walkthrough of a workflow showing the interaction between systems and the instances shared, possibly including the evolution of instances over time.



ExplanationOfBenefit

ExplanationOfBenefit

ExplanationOfBenefit. This resource provides: the claim details; adjudication details from the processing of a Claim; and optionally account balance information, for informing the subscriber of the benefits provided.



Expression

Expression

Expression. Expression Type: A expression that is evaluated in a specified context and returns a value. The context of use of the expression must specify the context in which the expression is evaluated, and how the result of the expression is used.



ExtendedContactDetail

ExtendedContactDetail

ExtendedContactDetail. ExtendedContactDetail Type: Specifies contact information for a specific purpose over a period of time, might be handled/monitored by a specific named person or organization.



Extension

Extension

Extension. Extension Type: Optional Extension Element - found in all resources.



FamilyMemberHistory

FamilyMemberHistory

FamilyMemberHistory. Significant health conditions for a person related to the patient relevant in the context of care for the patient.



Flag

Flag

Flag. Prospective warnings of potential issues when providing care to the patient.



FormularyItem

FormularyItem

FormularyItem. This resource describes a product or service that is available through a program and includes the conditions and constraints of availability. All of the information in this resource is specific to the inclusion of the item in the formulary and is not inherent to the item itself.



GenomicStudy

GenomicStudy

GenomicStudy. A set of analyses performed to analyze and generate genomic data.



Goal

Goal

Goal. Describes the intended objective(s) for a patient, group or organization care, for example, weight loss, restoring an activity of daily living, obtaining herd immunity via immunization, meeting a process improvement objective, etc.



GraphDefinition

GraphDefinition

GraphDefinition. A formal computable definition of a graph of resources - that is, a coherent set of resources that form a graph by following references. The Graph Definition resource defines a set and makes rules about the set.



Group

Group

Group. Represents a defined collection of entities that may be discussed or acted upon collectively but which are not expected to act collectively, and are not formally or legally recognized; i.e. a collection of entities that isn’t an Organization.



GuidanceResponse

GuidanceResponse

GuidanceResponse. A guidance response is the formal response to a guidance request, including any output parameters returned by the evaluation, as well as the description of any proposed actions to be taken.



HealthcareService

HealthcareService

HealthcareService. The details of a healthcare service available at a location or in a catalog. In the case where there is a hierarchy of services (for example, Lab -> Pathology -> Wound Cultures), this can be represented using a set of linked HealthcareServices.



HumanName

HumanName

HumanName. HumanName Type: A name, normally of a human, that can be used for other living entities (e.g. animals but not organizations) that have been assigned names by a human and may need the use of name parts or the need for usage information.



Identifier

Identifier

Identifier. Identifier Type: An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.



ImagingSelection

ImagingSelection

ImagingSelection. A selection of DICOM SOP instances and/or frames within a single Study and Series. This might include additional specifics such as an image region, an Observation UID or a Segmentation Number, allowing linkage to an Observation Resource or transferring this information along with the ImagingStudy Resource.



ImagingStudy

ImagingStudy

ImagingStudy. Representation of the content produced in a DICOM imaging study. A study comprises a set of series, each of which includes a set of Service-Object Pair Instances (SOP Instances - images or other data) acquired or produced in a common context. A series is of only one modality (e.g. X-ray, CT, MR, ultrasound), but a study may have multiple series of different modalities.



Immunization

Immunization

Immunization. Describes the event of a patient being administered a vaccine or a record of an immunization as reported by a patient, a clinician or another party.



ImmunizationEvaluation

ImmunizationEvaluation

ImmunizationEvaluation. Describes a comparison of an immunization event against published recommendations to determine if the administration is “valid” in relation to those recommendations.



ImmunizationRecommendation

ImmunizationRecommendation

ImmunizationRecommendation. A patient’s point-in-time set of recommendations (i.e. forecasting) according to a published schedule with optional supporting justification.



ImplementationGuide

ImplementationGuide

ImplementationGuide. A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.



Ingredient

Ingredient

Ingredient. An ingredient of a manufactured item or pharmaceutical product.



InsurancePlan

InsurancePlan

InsurancePlan. Details of a Health Insurance product/plan provided by an organization.



InventoryItem

InventoryItem

InventoryItem. functional description of an inventory item used in inventory and supply-related workflows.



InventoryReport

InventoryReport

InventoryReport. A report of inventory or stock items.



Invoice

Invoice

Invoice. Invoice containing collected ChargeItems from an Account with calculated individual and total price for Billing purpose.



Library

Library

Library. The Library resource is a general-purpose container for knowledge asset definitions. It can be used to describe and expose existing knowledge assets such as logic libraries and information model descriptions, as well as to describe a collection of knowledge assets.



Linkage

Linkage

Linkage. Identifies two or more records (resource instances) that refer to the same real-world “occurrence”.



List

List

List. A List is a curated collection of resources, for things such as problem lists, allergy lists, facility list, organization list, etc.



Location

Location

Location. Details and position information for a place where services are provided and resources and participants may be stored, found, contained, or accommodated.



ManufacturedItemDefinition

ManufacturedItemDefinition

ManufacturedItemDefinition. The definition and characteristics of a medicinal manufactured item, such as a tablet or capsule, as contained in a packaged medicinal product.



MarketingStatus

MarketingStatus

MarketingStatus. MarketingStatus Type: The marketing status describes the date when a medicinal product is actually put on the market or the date as of which it is no longer available.



Measure

Measure

Measure. The Measure resource provides the definition of a quality measure.



MeasureReport

MeasureReport

MeasureReport. The MeasureReport resource contains the results of the calculation of a measure; and optionally a reference to the resources involved in that calculation.



Medication

Medication

Medication. This resource is primarily used for the identification and definition of a medication, including ingredients, for the purposes of prescribing, dispensing, and administering a medication as well as for making statements about medication use.



MedicationAdministration

MedicationAdministration

MedicationAdministration. Describes the event of a patient consuming or otherwise being administered a medication. This may be as simple as swallowing a tablet or it may be a long running infusion. Related resources tie this event to the authorizing prescription, and the specific encounter between patient and health care practitioner. This event can also be used to record waste using a status of not-done and the appropriate statusReason.



MedicationDispense

MedicationDispense

MedicationDispense. Indicates that a medication product is to be or has been dispensed for a named person/patient. This includes a description of the medication product (supply) provided and the instructions for administering the medication. The medication dispense is the result of a pharmacy system responding to a medication order.



MedicationKnowledge

MedicationKnowledge

MedicationKnowledge. Information about a medication that is used to support knowledge.



MedicationRequest

MedicationRequest

MedicationRequest. An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called “MedicationRequest” rather than “MedicationPrescription” or “MedicationOrder” to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.



MedicationStatement

MedicationStatement

MedicationStatement. A record of a medication that is being consumed by a patient. A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future. The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician. A common scenario where this information is captured is during the history taking process during a patient visit or stay. The medication information may come from sources such as the patient’s memory, from a prescription bottle, or from a list of medications the patient, clinician or other party maintains.

The primary difference between a medicationstatement and a medicationadministration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication. A medicationstatement is often, if not always, less specific. There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise. As stated earlier, the Medication Statement information may come from the patient’s memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains. Medication administration is more formal and is not missing detailed information.



MedicinalProductDefinition

MedicinalProductDefinition

MedicinalProductDefinition. Detailed definition of a medicinal product, typically for uses other than direct patient care (e.g. regulatory use, drug catalogs, to support prescribing, adverse events management etc.).



MessageDefinition

MessageDefinition

MessageDefinition. Defines the characteristics of a message that can be shared between systems, including the type of event that initiates the message, the content to be transmitted and what response(s), if any, are permitted.



MessageHeader

MessageHeader

MessageHeader. The header for a message exchange that is either requesting or responding to an action. The reference(s) that are the subject of the action as well as other information related to the action are typically transmitted in a bundle in which the MessageHeader resource instance is the first resource in the bundle.



Meta

Meta

Meta. Meta Type: The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.



MetadataResource

MetadataResource

MetadataResource. Common Interface declaration for conformance and knowledge artifact resources.



MolecularSequence

MolecularSequence

MolecularSequence. Representation of a molecular sequence.



MonetaryComponent

MonetaryComponent

MonetaryComponent. MonetaryComponent Type: Availability data for an {item}.



Money

Money

Money. Money Type: An amount of economic utility in some recognized currency.



NamingSystem

NamingSystem

NamingSystem. A curated namespace that issues unique symbols within that namespace for the identification of concepts, people, devices, etc. Represents a “System” used within the Identifier and Coding data types.



Narrative

Narrative

Narrative. Narrative Type: A human-readable summary of the resource conveying the essential clinical and business information for the resource.



NutritionIntake

NutritionIntake

NutritionIntake. A record of food or fluid that is being consumed by a patient. A NutritionIntake may indicate that the patient may be consuming the food or fluid now or has consumed the food or fluid in the past. The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician. A common scenario where this information is captured is during the history taking process during a patient visit or stay or through an app that tracks food or fluids consumed. The consumption information may come from sources such as the patient’s memory, from a nutrition label, or from a clinician documenting observed intake.



NutritionOrder

NutritionOrder

NutritionOrder. A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident.



NutritionProduct

NutritionProduct

NutritionProduct. A food or supplement that is consumed by patients.



Observation

Observation

Observation. Measurements and simple assertions made about a patient, device or other subject.



ObservationDefinition

ObservationDefinition

ObservationDefinition. Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.



OperationDefinition

OperationDefinition

OperationDefinition. A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction).



OperationOutcome

OperationOutcome

OperationOutcome. A collection of error, warning, or information messages that result from a system action.



Organization

Organization

Organization. A formally or informally recognized grouping of people or organizations formed for the purpose of achieving some form of collective action. Includes companies, institutions, corporations, departments, community groups, healthcare practice groups, payer/insurer, etc.



OrganizationAffiliation

OrganizationAffiliation

OrganizationAffiliation. Defines an affiliation/assotiation/relationship between 2 distinct organizations, that is not a part-of relationship/sub-division relationship.



PackagedProductDefinition

PackagedProductDefinition

PackagedProductDefinition. A medically related item or items, in a container or package.



ParameterDefinition

ParameterDefinition

ParameterDefinition. ParameterDefinition Type: The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.



Parameters

Parameters

Parameters. This resource is used to pass information into and back from an operation (whether invoked directly from REST or within a messaging environment). It is not persisted or allowed to be referenced by other resources except as described in the definition of the Parameters resource.



Patient

Patient

Patient. Demographics and other administrative information about an individual or animal receiving care or other health-related services.



PaymentNotice

PaymentNotice

PaymentNotice. This resource provides the status of the payment for goods and services rendered, and the request and response resource references.



PaymentReconciliation

PaymentReconciliation

PaymentReconciliation. This resource provides the details including amount of a payment and allocates the payment items being paid.



Period

Period

Period. Period Type: A time period defined by a start and end date and optionally time.



Permission

Permission

Permission. Permission resource holds access rules for a given data and context.



Person

Person

Person. Demographics and administrative information about a person independent of a specific health-related context.



PlanDefinition

PlanDefinition

PlanDefinition. This resource allows for the definition of various types of plans as a sharable, consumable, and executable artifact. The resource is general enough to support the description of a broad range of clinical and non-clinical artifacts such as clinical decision support rules, order sets, protocols, and drug quality specifications.



Practitioner

Practitioner

Practitioner. A person who is directly or indirectly involved in the provisioning of healthcare or related services.



PractitionerRole

PractitionerRole

PractitionerRole. A specific set of Roles/Locations/specialties/services that a practitioner may perform, or has performed at an organization during a period of time.



PrimitiveType

PrimitiveType

PrimitiveType. PrimitiveType Type: The base type for all re-useable types defined that have a simple property.



Procedure

Procedure

Procedure. An action that is or was performed on or for a patient, practitioner, device, organization, or location. For example, this can be a physical intervention on a patient like an operation, or less invasive like long term services, counseling, or hypnotherapy. This can be a quality or safety inspection for a location, organization, or device. This can be an accreditation procedure on a practitioner for licensing.



ProductShelfLife

ProductShelfLife

ProductShelfLife. ProductShelfLife Type: The shelf-life and storage information for a medicinal product item or container can be described using this class.



Provenance

Provenance

Provenance. Provenance of a resource is a record that describes entities and processes involved in producing and delivering or otherwise influencing that resource. Provenance provides a critical foundation for assessing authenticity, enabling trust, and allowing reproducibility. Provenance assertions are a form of contextual metadata and can themselves become important records with their own provenance. Provenance statement indicates clinical significance in terms of confidence in authenticity, reliability, and trustworthiness, integrity, and stage in lifecycle (e.g. Document Completion - has the artifact been legally authenticated), all of which may impact security, privacy, and trust policies.



Quantity

Quantity

Quantity. Quantity Type: A measured amount (or an amount that can potentially be measured). Note that measured amounts include amounts that are not precisely quantified, including amounts involving arbitrary units and floating currencies.



Questionnaire

Questionnaire

Questionnaire. A structured set of questions intended to guide the collection of answers from end-users. Questionnaires provide detailed control over order, presentation, phraseology and grouping to allow coherent, consistent data collection.



QuestionnaireResponse

QuestionnaireResponse

QuestionnaireResponse. A structured set of questions and their answers. The questions are ordered and grouped into coherent subsets, corresponding to the structure of the grouping of the questionnaire being responded to.



Range

Range

Range. Range Type: A set of ordered Quantities defined by a low and high limit.



Ratio

Ratio

Ratio. Ratio Type: A relationship of two Quantity values - expressed as a numerator and a denominator.



RatioRange

RatioRange

RatioRange. RatioRange Type: A range of ratios expressed as a low and high numerator and a denominator.



Reference

Reference

Reference. Reference Type: A reference from one resource to another.



RegulatedAuthorization

RegulatedAuthorization

RegulatedAuthorization. Regulatory approval, clearance or licencing related to a regulated product, treatment, facility or activity that is cited in a guidance, regulation, rule or legislative act. An example is Market Authorization relating to a Medicinal Product.



RelatedArtifact

RelatedArtifact

RelatedArtifact. RelatedArtifact Type: Related artifacts such as additional documentation, justification, or bibliographic references.



RelatedPerson

RelatedPerson

RelatedPerson. Information about a person that is involved in a patient’s health or the care for a patient, but who is not the target of healthcare, nor has a formal responsibility in the care process.



RequestOrchestration

RequestOrchestration

RequestOrchestration. A set of related requests that can be used to capture intended activities that have inter-dependencies such as “give this medication after that one”.



Requirements

Requirements

Requirements. The Requirements resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.



ResearchStudy

ResearchStudy

ResearchStudy. A scientific study of nature that sometimes includes processes involved in health and disease. For example, clinical trials are research studies that involve people. These studies may be related to new ways to screen, prevent, diagnose, and treat disease. They may also study certain outcomes and certain groups of people by looking at data collected in the past or future.



ResearchSubject

ResearchSubject

ResearchSubject. A ResearchSubject is a participant or object which is the recipient of investigative activities in a research study.



Resource

Resource

Resource. This is the base resource type for everything.



RiskAssessment

RiskAssessment

RiskAssessment. An assessment of the likely outcome(s) for a patient or other subject as well as the likelihood of each outcome.



SampledData

SampledData

SampledData. SampledData Type: A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data.



Schedule

Schedule

Schedule. A container for slots of time that may be available for booking appointments.



SearchParameter

SearchParameter

SearchParameter. A search parameter that defines a named search item that can be used to search/filter on a resource.



ServiceRequest

ServiceRequest

ServiceRequest. A record of a request for service such as diagnostic investigations, treatments, or operations to be performed.



Signature

Signature

Signature. Signature Type: A signature along with supporting context. The signature may be a digital signature that is cryptographic in nature, or some other signature acceptable to the domain. This other signature may be as simple as a graphical image representing a hand-written signature, or a signature ceremony Different signature approaches have different utilities.



Slot

Slot

Slot. A slot of time on a schedule that may be available for booking appointments.



Specimen

Specimen

Specimen. A sample to be used for analysis.



SpecimenDefinition

SpecimenDefinition

SpecimenDefinition. A kind of specimen with associated set of requirements.



StructureDefinition

StructureDefinition

StructureDefinition. A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types.



StructureMap

StructureMap

StructureMap. A Map of relationships between 2 structures that can be used to transform data.



Subscription

Subscription

Subscription. The subscription resource describes a particular client’s request to be notified about a SubscriptionTopic.



SubscriptionStatus

SubscriptionStatus

SubscriptionStatus. The SubscriptionStatus resource describes the state of a Subscription during notifications. It is not persisted.



SubscriptionTopic

SubscriptionTopic

SubscriptionTopic. Describes a stream of resource state changes identified by trigger criteria and annotated with labels useful to filter projections from this topic.



Substance

Substance

Substance. A homogeneous material with a definite composition.



SubstanceDefinition

SubstanceDefinition

SubstanceDefinition. The detailed description of a substance, typically at a level beyond what is used for prescribing.



SubstanceNucleicAcid

SubstanceNucleicAcid

SubstanceNucleicAcid. Nucleic acids are defined by three distinct elements: the base, sugar and linkage. Individual substance/moiety IDs will be created for each of these elements. The nucleotide sequence will be always entered in the 5’-3’ direction.



SubstancePolymer

SubstancePolymer

SubstancePolymer. Properties of a substance specific to it being a polymer.



SubstanceProtein

SubstanceProtein

SubstanceProtein. A SubstanceProtein is defined as a single unit of a linear amino acid sequence, or a combination of subunits that are either covalently linked or have a defined invariant stoichiometric relationship. This includes all synthetic, recombinant and purified SubstanceProteins of defined sequence, whether the use is therapeutic or prophylactic. This set of elements will be used to describe albumins, coagulation factors, cytokines, growth factors, peptide/SubstanceProtein hormones, enzymes, toxins, toxoids, recombinant vaccines, and immunomodulators.



SubstanceReferenceInformation

SubstanceReferenceInformation

SubstanceReferenceInformation. Todo.



SubstanceSourceMaterial

SubstanceSourceMaterial

SubstanceSourceMaterial. Source material shall capture information on the taxonomic and anatomical origins as well as the fraction of a material that can result in or can be modified to form a substance. This set of data elements shall be used to define polymer substances isolated from biological matrices. Taxonomic and anatomical origins shall be described using a controlled vocabulary as required. This information is captured for naturally derived polymers ( . starch) and structurally diverse substances. For Organisms belonging to the Kingdom Plantae the Substance level defines the fresh material of a single species or infraspecies, the Herbal Drug and the Herbal preparation. For Herbal preparations, the fraction information will be captured at the Substance information level and additional information for herbal extracts will be captured at the Specified Substance Group 1 information level. See for further explanation the Substance Class: Structurally Diverse and the herbal annex.



SupplyDelivery

SupplyDelivery

SupplyDelivery. Record of delivery of what is supplied.



SupplyRequest

SupplyRequest

SupplyRequest. A record of a non-patient specific request for a medication, substance, device, certain types of biologically derived product, and nutrition product used in the healthcare setting.



Task

Task

Task. A task to be performed.



TerminologyCapabilities

TerminologyCapabilities

TerminologyCapabilities. A TerminologyCapabilities resource documents a set of capabilities (behaviors) of a FHIR Terminology Server that may be used as a statement of actual server functionality or a statement of required or desired server implementation.



TestPlan

TestPlan

TestPlan. A plan for executing testing on an artifact or specifications



TestReport

TestReport

TestReport. A summary of information based on the results of executing a TestScript.



TestScript

TestScript

TestScript. A structured set of tests against a FHIR server or client implementation to determine compliance against the FHIR specification.



Timing

Timing

Timing. Timing Type: Specifies an event that may occur multiple times. Timing schedules are used to record when things are planned, expected or requested to occur. The most common usage is in dosage instructions for medications. They are also used when planning care of various kinds, and may be used for reporting the schedule to which past regular activities were carried out.



Transport

Transport

Transport. Record of transport.



TriggerDefinition

TriggerDefinition

TriggerDefinition. TriggerDefinition Type: A description of a triggering event. Triggering events can be named events, data events, or periodic, as determined by the type element.



UsageContext

UsageContext

UsageContext. UsageContext Type: Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care).



ValueSet

ValueSet

ValueSet. A ValueSet resource instance specifies a set of codes drawn from one or more code systems, intended for use in a particular context. Value sets link between [[[CodeSystem]]] definitions and their use in coded elements.



VerificationResult

VerificationResult

VerificationResult. Describes validation requirements, source(s), status and dates for one or more elements.



VirtualServiceDetail

VirtualServiceDetail

VirtualServiceDetail. VirtualServiceDetail Type: Virtual Service Contact Details.



VisionPrescription

VisionPrescription

VisionPrescription. An authorization for the provision of glasses and/or contact lenses to a patient.



Base64Binary

base64Binary

base64Binary. base64Binary Type: A stream of bytes



Boolean

boolean

boolean. boolean Type: Value of “true” or “false”



Canonical

canonical

canonical. canonical type: A URI that is a reference to a canonical URL on a FHIR resource



Code

code

code. code type: A string which has at least one character and no leading or trailing whitespace and where there is no whitespace other than single spaces in the contents



Date

date

date. date Type: A date or partial date (e.g. just year or year + month). There is no UTC offset. The format is a union of the schema types gYear, gYearMonth and date. Dates SHALL be valid dates.



DateTime

dateTime

dateTime. dateTime Type: A date, date-time or partial date (e.g. just year or year + month). If hours and minutes are specified, a UTC offset SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored. Dates SHALL be valid dates.



Decimal

decimal

decimal. decimal Type: A rational number with implicit precision



Id

id

id. id type: Any combination of letters, numerals, “-” and “.”, with a length limit of 64 characters. (This might be an integer, an unprefixed OID, UUID or any other identifier pattern that meets these constraints.) Ids are case-insensitive.



Instant

instant

instant. instant Type: An instant in time - known at least to the second



Integer

integer

integer. integer Type: A whole number



Integer64

integer64

integer64. integer64 Type: A very large whole number



Markdown

markdown

markdown. markdown type: A string that may contain Github Flavored Markdown syntax for optional processing by a mark down presentation engine



Oid

oid

oid. oid type: An OID represented as a URI



PositiveInt

positiveInt

positiveInt. positiveInt type: An integer with a value that is positive (e.g. >0)



String

string

string. string Type: A sequence of Unicode characters



Time

time

time. time Type: A time during the day, with no date specified



UnsignedInt

unsignedInt

unsignedInt. unsignedInt type: An integer with a value that is not negative (e.g. >= 0)



Uri

uri

uri. uri Type: String of characters used to identify a name or a resource



Url

url

url. url type: A URI that is a literal reference



Uuid

uuid

uuid. uuid type: A UUID, represented as a URI



Xhtml

xhtml

xhtml. xhtml Type definition