pub enum GraphCompartmentUse {
Requires,
Where,
}Expand description
GraphCompartmentUse. Defines how a compartment rule is used.
FHIR version: 5.0.0.
Variants
Requires
requires
requires. This compartment rule is enforced on any relationships that meet the conditions.
Where
where
Where. This compartment rule is a condition for whether the rule applies.