pub enum GuidePageGeneration {
Generated,
Html,
Markdown,
Xml,
}Expand description
GuidePageGeneration. A code that indicates how the page is generated.
FHIR version: 5.0.0.
Variants
Generated
generated
Generated. Page will be generated by the publication process - no source to bring across.
Html
html
HTML. Page is proper xhtml with no templating. Will be brought across unchanged for standard post-processing.
Markdown
markdown
Markdown. Page is markdown with templating. Will use the template to create a file that imports the markdown file prior to post-processing.
Xml
xml
XML. Page is xml with templating. Will use the template to create a file that imports the source file and run the nominated XSLT transform (see parameters) if present prior to post-processing.