pub enum GuideParameterCode {
Apply,
ExpansionParameter,
GenerateJson,
GenerateTurtle,
GenerateXml,
HtmlTemplate,
PathPages,
PathResource,
PathTxCache,
RuleBrokenLinks,
_Custom(String),
}Expand description
GuideParameterCode. GuideParameterCode
FHIR version: 5.0.0.
Variants
Apply
apply
Apply Metadata Value. If the value of this string 0..* parameter is one of the metadata fields then all conformance resources will have any specified [Resource].[field] overwritten with the ImplementationGuide.[field], where field is one of: version, date, status, publisher, contact, copyright, experimental, jurisdiction, useContext.
ExpansionParameter
expansion-parameter
Expansion Profile. The value of this string 0..* parameter is a parameter (name=value) when expanding value sets for this implementation guide. This is particularly used to specify the versions of published terminologies such as SNOMED CT.
GenerateJson
generate-json
Generate JSON. The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in JSON format. If not present, the Publication Tool decides whether to generate JSON.
GenerateTurtle
generate-turtle
Generate Turtle. The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in Turtle format. If not present, the Publication Tool decides whether to generate Turtle.
GenerateXml
generate-xml
Generate XML. The value of this boolean 0..1 parameter specifies whether the IG publisher creates examples in XML format. If not present, the Publication Tool decides whether to generate XML.
HtmlTemplate
html-template
HTML Template. The value of this string singleton parameter is the name of the file to use as the builder template for each generated page (see templating).
PathPages
path-pages
Pages Path. The value of this string 0..1 parameter is a subfolder of the build context’s location that contains files that are part of the html content processed by the builder.
PathResource
path-resource
Resource Path. The value of this string 0..* parameter is a subfolder of the build context’s location that is to be scanned to load resources. Scope is (if present) a particular resource type.
PathTxCache
path-tx-cache
Terminology Cache Path. The value of this string 0..1 parameter is a subfolder of the build context’s location that is used as the terminology cache. If this is not present, the terminology cache is on the local system, not under version control.
RuleBrokenLinks
rule-broken-links
Broken Links Rule. The value of this string 0..1 parameter is either “warning” or “error” (default = “error”). If the value is “warning” then IG build tools allow the IG to be considered successfully build even when there is no internal broken links.
_Custom(String)
Custom code value.