InvoiceStatus

Enum InvoiceStatus 

pub enum InvoiceStatus {
    Balanced,
    Cancelled,
    Draft,
    EnteredInError,
    Issued,
}
InvoiceStatus. Codes identifying the lifecycle stage of an Invoice.

FHIR version: 5.0.0.

Variants



Balanced

balanced

balanced. the invoice has been balaced / completely paid.



Cancelled

cancelled

cancelled. the invoice was cancelled.



Draft

draft

draft. the invoice has been prepared but not yet finalized.



EnteredInError

entered-in-error

entered in error. the invoice was determined as entered in error before it was issued.



Issued

issued

issued. the invoice has been finalized and sent to the recipient.