IssueSeverity

Enum IssueSeverity 

pub enum IssueSeverity {
    Error,
    Fatal,
    Information,
    Success,
    Warning,
}
IssueSeverity. How the issue affects the success of the action.

FHIR version: 5.0.0.

Variants



Error

error

Error. The issue is sufficiently important to cause the action to fail.



Fatal

fatal

Fatal. The issue caused the action to fail and no further checking could be performed.



Information

information

Information. The issue has no relation to the degree of success of the action.



Success

success

Operation Successful. The operation completed successfully.



Warning

warning

Warning. The issue is not important enough to cause the action to fail but may cause it to be performed suboptimally or in a way that is not as desired.