pub enum MeasureAggregateMethod {
Average,
Count,
Maximum,
Median,
Minimum,
Sum,
}Expand description
MeasureAggregateMethod. Aggregation method for a measure (e.g. sum, average, median, minimum, maximum, count)
FHIR version: 5.0.0.
Variants
Average
average
Average. The measure score is determined by taking the average of the observations derived from the measure population.
Count
count
Count. The measure score is determined as the number of observations derived from the measure population.
Maximum
maximum
Maximum. The measure score is determined by taking the maximum of the observations derived from the measure population.
Median
median
Median. The measure score is determined by taking the median of the observations derived from the measure population.
Minimum
minimum
Minimum. The measure score is determined by taking the minimum of the observations derived from the measure population.
Sum
sum
Sum. The measure score is determined by adding together the observations derived from the measure population.