pub enum MeasureReportType {
DataExchange,
Individual,
SubjectList,
Summary,
}Expand description
MeasureReportType. The type of the measure report.
FHIR version: 5.0.0.
Variants
DataExchange
data-exchange
Data Exchange. A data exchange report that contains data-of-interest for the measure (i.e. data that is needed to calculate the measure)
Individual
individual
Individual. An individual report that provides information on the performance for a given measure with respect to a single subject.
SubjectList
subject-list
Subject List. A subject list report that includes a listing of subjects that satisfied each population criteria in the measure.
Summary
summary
Summary. A summary report that returns the number of members in each population criteria for the measure.