pub enum MedicationAdministrationStatusCodes {
Completed,
EnteredInError,
InProgress,
NotDone,
OnHold,
Stopped,
Unknown,
}Expand description
MedicationAdministrationStatusCodes. MedicationAdministration Status Codes
FHIR version: 5.0.0.
Variants
Completed
completed
Completed. All actions that are implied by the administration have occurred.
EnteredInError
entered-in-error
Entered in Error. The administration was entered in error and therefore nullified.
InProgress
in-progress
In Progress. The administration has started but has not yet completed.
NotDone
not-done
Not Done. The administration was terminated prior to any impact on the subject (though preparatory actions may have been taken)
OnHold
on-hold
On Hold. Actions implied by the administration have been temporarily halted, but are expected to continue later. May also be called ‘suspended’.
Stopped
stopped
Stopped. Actions implied by the administration have been permanently halted, before all of them occurred.
Unknown
unknown
Unknown. The authoring system does not know which of the status values currently applies for this request. Note: This concept is not to be used for ‘other’ - one of the listed statuses is presumed to apply, it’s just not known which one.