pub enum MedicationKnowledgeStatusCodes {
Active,
EnteredInError,
Inactive,
}Expand description
MedicationKnowledgeStatusCodes. MedicationKnowledge Status Codes
FHIR version: 5.0.0.
Variants
Active
active
Active. The medication referred to by this MedicationKnowledge is in active use within the drug database or inventory system.
EnteredInError
entered-in-error
Entered in Error. The medication referred to by this MedicationKnowledge was entered in error within the drug database or inventory system.
Inactive
inactive
Inactive. The medication referred to by this MedicationKnowledge is not in active use within the drug database or inventory system.