pub enum MedicationRequestStatusCodes {
Active,
Cancelled,
Completed,
Draft,
Ended,
EnteredInError,
OnHold,
Stopped,
Unknown,
}Expand description
MedicationRequestStatusCodes. MedicationRequest Status Codes
FHIR version: 5.0.0.
Variants
Active
active
Active. The request is ‘actionable’, but not all actions that are implied by it have occurred yet.
Cancelled
cancelled
Cancelled. The request has been withdrawn before any administrations have occurred
Completed
completed
Completed. All actions that are implied by the request have occurred.
Draft
draft
Draft. The request is not yet ‘actionable’, e.g. it is a work in progress, requires sign-off, verification or needs to be run through decision support process.
Ended
ended
Ended. The request is no longer active and the subject should no longer be taking the medication.
EnteredInError
entered-in-error
Entered in Error. The request was recorded against the wrong patient or for some reason should not have been recorded (e.g. wrong medication, wrong dose, etc.). Some of the actions that are implied by the medication request may have occurred. For example, the medication may have been dispensed and the patient may have taken some of the medication.
OnHold
on-hold
On Hold. Actions implied by the request are to be temporarily halted. The request might or might not be resumed. May also be called ‘suspended’.
Stopped
stopped
Stopped. Actions implied by the request are to be permanently halted, before all of the administrations occurred. This should not be used if the original order was entered in error
Unknown
unknown
Unknown. The authoring/source system does not know which of the status values currently applies for this request. Note: This concept is not to be used for ‘other’ - one of the listed statuses is presumed to apply, but the authoring/source system does not know which.