MedicationStatusCodes

Enum MedicationStatusCodes 

pub enum MedicationStatusCodes {
    Active,
    EnteredInError,
    Inactive,
}
MedicationStatusCodes. Medication Status Codes

FHIR version: 5.0.0.

Variants



Active

active

Active. The medication record is current and is appropriate for reference in new instances.



EnteredInError

entered-in-error

Entered in Error. The medication record was created erroneously and is not appropriated for reference in new instances.



Inactive

inactive

Inactive. The medication record is not current and is not is appropriate for reference in new instances.