NameUse

Enum NameUse 

pub enum NameUse {
    Anonymous,
    Maiden,
    Nickname,
    Official,
    Old,
    Temp,
    Usual,
}
NameUse. The use of a human name.

FHIR version: 5.0.0.

Variants



Anonymous

anonymous

Anonymous. Anonymous assigned name, alias, or pseudonym (used to protect a person’s identity for privacy reasons).



Maiden

maiden

Name changed for Marriage. A name used prior to changing name because of marriage. This name use is for use by applications that collect and store names that were used prior to a marriage. Marriage naming customs vary greatly around the world, and are constantly changing. This term is not gender specific. The use of this term does not imply any particular history for a person’s name.



Nickname

nickname

Nickname. A name that is used to address the person in an informal manner, but is not part of their formal or usual name.



Official

official

Official. The formal name as registered in an official (government) registry, but which name might not be commonly used. May be called “legal name”.



Old

old

Old. This name is no longer in use (or was never correct, but retained for records).



Temp

temp

Temp. A temporary name. Name.period can provide more detailed information. This may also be used for temporary names assigned at birth or in emergency situations.



Usual

usual

Usual. Known as/conventional/the one you normally use.