pub enum NamingSystemType {
Codesystem,
Identifier,
Root,
}Expand description
NamingSystemType. Identifies the purpose of the naming system.
FHIR version: 5.0.0.
Variants
Codesystem
codesystem
Code System. The naming system is used to define concepts and symbols to represent those concepts; e.g. UCUM, LOINC, NDC code, local lab codes, etc.
Identifier
identifier
Identifier. The naming system is used to manage identifiers (e.g. license numbers, order numbers, etc.).
Root
root
Root. The naming system is used as the root for other identifiers and naming systems.