pub enum ObservationDataType {
CodeableConcept,
Period,
Quantity,
Range,
Ratio,
SampledData,
Boolean,
DateTime,
Integer,
String,
Time,
}Expand description
ObservationDataType. Permitted data type for observation value.
FHIR version: 5.0.0.
Variants
CodeableConcept
CodeableConcept
CodeableConcept. A coded concept from a reference terminology and/or text.
Period
Period
Period. A time range defined by start and end date/time.
Quantity
Quantity
Quantity. A measured amount.
Range
Range
Range. A set of values bounded by low and high.
Ratio
Ratio
Ratio. A ratio of two Quantity values - a numerator and a denominator.
SampledData
SampledData
SampledData. A series of measurements taken by a device.
Boolean
boolean
boolean. true or false.
DateTime
dateTime
dateTime. A date, date-time or partial date (e.g. just year or year + month) as used in human communication.
Integer
integer
integer. A signed integer.
String
string
string. A sequence of Unicode characters.
Time
time
time. A time during the day, in the format hh:mm:ss.