pub enum ObservationReferenceRangeNormalValue {
Absent,
Negative,
}Expand description
ObservationReferenceRangeNormalValue. Codes that describe the normal value in the reference range.
FHIR version: 5.0.0.
Variants
Absent
absent
Absent. The expected normal value for the observation is absent.
Negative
negative
Negative. The expected normal value for the observation is negative.