PriceComponentType

Enum PriceComponentType 

pub enum PriceComponentType {
    Base,
    Deduction,
    Discount,
    Informational,
    Surcharge,
    Tax,
}
PriceComponentType. Codes indicating the kind of the price component.

FHIR version: 5.0.0.

Variants



Base

base

base price. the amount is the base price used for calculating the total price before applying surcharges, discount or taxes.



Deduction

deduction

deduction. the amount is a deduction applied on the base price.



Discount

discount

discount. the amount is a discount applied on the base price.



Informational

informational

informational. the amount is of informational character, it has not been applied in the calculation of the total price.



Surcharge

surcharge

surcharge. the amount is a surcharge applied on the base price.



Tax

tax

tax. the amount is the tax component of the total price.