pub enum PublishedInType {
D001877,
D019991,
D020492,
D064886,
}Expand description
PublishedInType. The type of publication such as book, database, or journal.
FHIR version: 5.0.0.
Variants
D001877
D001877
Book. Non-periodical written or printed works consisting of sheets of pages fastened or bound together within covers.
D019991
D019991
Database. A structured file of information or a set of logically related data stored and retrieved using computer-based means.
D020492
D020492
Periodical. Publication intended to be issued on an ongoing basis, generally more frequently than annually, containing separate articles, stories, or writings.
D064886
D064886
Dataset. Works consisting of organized collections of data, which have been stored permanently in a formalized manner suitable for communication, interpretation, or processing.