QuestionnaireItemOperator

Enum QuestionnaireItemOperator 

pub enum QuestionnaireItemOperator {
    NotEqual,
    Less,
    LessOrEqual,
    Equal,
    Greater,
    GreaterOrEqual,
    Exists,
}
QuestionnaireItemOperator. The criteria by which a question is enabled.

FHIR version: 5.0.0.

Variants



NotEqual

!=

Not Equals. True if no answer has a value that is equal to the enableWhen answer.



Less

<

Less Than. True if at least one answer has a value that is less than the enableWhen answer.



LessOrEqual

<=

Less or Equals. True if at least one answer has a value that is less or equal to the enableWhen answer.



Equal

=

Equals. True if at least one answer has a value that is equal to the enableWhen answer.



Greater

>

Greater Than. True if at least one answer has a value that is greater than the enableWhen answer.



GreaterOrEqual

>=

Greater or Equals. True if at least one answer has a value that is greater or equal to the enableWhen answer.



Exists

exists

Exists. True if the determination of ‘whether an answer exists for the question’ is equal to the enableWhen answer (which must be a boolean).