QuestionnaireResponseStatus

Enum QuestionnaireResponseStatus 

pub enum QuestionnaireResponseStatus {
    Amended,
    Completed,
    EnteredInError,
    InProgress,
    Stopped,
}
QuestionnaireResponseStatus. Lifecycle status of the questionnaire response.

FHIR version: 5.0.0.

Variants



Amended

amended

Amended. This QuestionnaireResponse has been filled out with answers, then marked as complete, yet changes or additions have been made to it afterwards.



Completed

completed

Completed. This QuestionnaireResponse has been filled out with answers and the current content is regarded as definitive.



EnteredInError

entered-in-error

Entered in Error. This QuestionnaireResponse was entered in error and voided.



InProgress

in-progress

In Progress. This QuestionnaireResponse has been partially filled out with answers but changes or additions are still expected to be made to it.



Stopped

stopped

Stopped. This QuestionnaireResponse has been partially filled out with answers but has been abandoned. No subsequent changes can be made.