pub enum ReferenceHandlingPolicy {
Enforced,
Literal,
Local,
Logical,
Resolves,
}Expand description
ReferenceHandlingPolicy. A set of flags that defines how references are supported.
FHIR version: 5.0.0.
Variants
Enforced
enforced
Reference Integrity Enforced. The server enforces that references have integrity - e.g. it ensures that references can always be resolved. This is typically the case for clinical record systems, but often not the case for middleware/proxy systems.
Literal
literal
Literal References. The server supports and populates Literal references (i.e. using Reference.reference) where they are known (this code does not guarantee that all references are literal; see ‘enforced’).
Local
local
Local References Only. The server does not support references that point to other servers.
Logical
logical
Logical References. The server allows logical references (i.e. using Reference.identifier).
Resolves
resolves
Resolves References. The server will attempt to resolve logical references to literal references - i.e. converting Reference.identifier to Reference.reference (if resolution fails, the server may still accept resources; see logical).