ReportSectionType

Enum ReportSectionType 

pub enum ReportSectionType {
Show 28 variants Assertion, CertaintyOfEvidence, ColumnHeader, ColumnHeaders, ControlGroupAloneEvidence, EfficacyOutcomes, Evidence, EvidenceClassifier, EvidenceVariable, EvidenceVariableExposure, EvidenceVariableIntended, EvidenceVariableObserved, EvidenceVariableOutcome, EvidenceVariablePopulation, HarmsOutcomes, Header, InterventionGroupAloneEvidence, InterventionVsControlEvidence, Reasons, References, RowHeaders, SampleSize, SummaryOfBodyOfEvidenceFindings, SummaryOfIndividualStudyFindings, Table, Tables, TextSummary, Warnings,
}
ReportSectionType. Evidence Report Section Type.

FHIR version: 5.0.0.

Variants



Assertion

Assertion

Assertion. Assertion.



CertaintyOfEvidence

Certainty-of-Evidence

Certainty of Evidence. Certainty of Evidence.



ColumnHeader

Column-Header

Column Header. Denotes the header to use for the column for a tabular report.



ColumnHeaders

Column-Headers

Column Headers. Denotes a section specifying column headers for a tabular report.



ControlGroupAloneEvidence

Control-group-alone-Evidence

Evidence Results for the control exposure only. Evidence Results for the control exposure only.



EfficacyOutcomes

Efficacy-outcomes

Efficacy-outcomes. Outcomes related to efficacy or potential benefits of interventions.



Evidence

Evidence

Evidence Results. Evidence Results.



EvidenceClassifier

Evidence-Classifier

Evidence Classifier section. This section is used for classifiers of the evidence.



EvidenceVariable

EvidenceVariable

Evidence Variables used. Evidence Variables used.



EvidenceVariableExposure

EvidenceVariable-exposure

Evidence Variable in variable role Exposure. Evidence Variable in variable role Exposure.



EvidenceVariableIntended

EvidenceVariable-intended

Evidence Variables intended for interpretation. Evidence Variables intended for interpretation.



EvidenceVariableObserved

EvidenceVariable-observed

Evidence Variables actually observed. Evidence Variables as observed in the research data.



EvidenceVariableOutcome

EvidenceVariable-outcome

Evidence Variable in variable role Outcome (MeasuredVariable). Evidence Variable in variable role Outcome (MeasuredVariable).



EvidenceVariablePopulation

EvidenceVariable-population

Evidence Variable in variable role Population. Evidence Variable in variable role Population.



HarmsOutcomes

Harms-outcomes

Harms outcomes. Outcomes related to adverse effects or potential harms of interventions.



Header

Header

Header. Denotes the header to use for a Text Summary or above a Table.



InterventionGroupAloneEvidence

Intervention-group-alone-Evidence

Evidence Results for the intervention exposure only. Evidence Results for the intervention exposure only.



InterventionVsControlEvidence

Intervention-vs-Control-Evidence

Evidence Results for comparison of Intervention and Control. Evidence Results for comparison of Intervention and Control.



Reasons

Reasons

Reasons. Reasons.



References

References

References. References.



RowHeaders

Row-Headers

Row Headers. Denotes a section specifying row headers for a tabular report.



SampleSize

SampleSize

Sample Size. Sample Size.



SummaryOfBodyOfEvidenceFindings

SummaryOfBodyOfEvidenceFindings

Summary of Body of Evidence Findings. Summary of Body of Evidence Findings.



SummaryOfIndividualStudyFindings

SummaryOfIndividualStudyFindings

Summary of Individual Study Findings. Summary of Individual Study Findings.



Table

Table

Table.



Tables

Tables

Tables. Tables.



TextSummary

Text-Summary

Text Summary. Denotes a section specifying text summary for a report.



Warnings

Warnings

Warnings. Warnings.