pub enum RequestIntent {
Directive,
FillerOrder,
InstanceOrder,
Option,
Order,
OriginalOrder,
Plan,
Proposal,
ReflexOrder,
}Expand description
RequestIntent. Codes indicating the degree of authority/intentionality associated with a request.
FHIR version: 5.0.0.
Variants
Directive
directive
Directive. The request represents a legally binding instruction authored by a Patient or RelatedPerson.
FillerOrder
filler-order
Filler Order. The request represents the view of an authorization instantiated by a fulfilling system representing the details of the fulfiller’s intention to act upon a submitted order.
InstanceOrder
instance-order
Instance Order. An order created in fulfillment of a broader order that represents the authorization for a single activity occurrence. E.g. The administration of a single dose of a drug.
Option
option
Option. The request represents a component or option for a RequestOrchestration that establishes timing, conditionality and/or other constraints among a set of requests. Refer to [[[RequestOrchestration]]] for additional information on how this status is used.
Order
order
Order. The request represents a request/demand and authorization for action by the requestor.
OriginalOrder
original-order
Original Order. The request represents an original authorization for action.
Plan
plan
Plan. The request represents an intention to ensure something occurs without providing an authorization for others to act.
Proposal
proposal
Proposal. The request is a suggestion made by someone/something that does not have an intention to ensure it occurs and without providing an authorization to act.
ReflexOrder
reflex-order
Reflex Order. The request represents an automatically generated supplemental authorization for action based on a parent authorization together with initial results of the action taken against that parent authorization.