pub enum ResearchStudyClassifiers {
FdaRegulatedDevice,
FdaRegulatedDrug,
IrbExempt,
MpgParagraph23b,
}Expand description
ResearchStudyClassifiers. Codes for use in ResearchStudy Resource. This resource (this entire set of content) is being used for active development of a ResearchStudyClassifiers CodeSystem for use for supporting multiple value sets in the FHIR ResearchStudy StructureDefinition.
FHIR version: 5.0.0.
Variants
FdaRegulatedDevice
fda-regulated-device
FDA regulated device. A medical device regulated by the U.S. Food and Drug Administration.
FdaRegulatedDrug
fda-regulated-drug
FDA regulated drug. A medication regulated by the U.S. Food and Drug Administration.
IrbExempt
irb-exempt
IRB-exempt. Human subjects research that is excempt from oversight and monitoring by an institutional review board (IRB).
MpgParagraph23b
mpg-paragraph-23b
MPG Paragraph 23b. Research regulated by a specific German legal requirement (Medizinproduktegesetz MPG Paragraph 23b).