pub enum ResearchStudyObjectiveType {
Exploratory,
Primary,
Secondary,
}Expand description
ResearchStudyObjectiveType. Codes for the kind of study objective.
FHIR version: 5.0.0.
Variants
Exploratory
exploratory
Exploratory. Exploratory questions to be answered in the study.
Primary
primary
Primary. The main question to be answered, and the one that drives any statistical planning for the study—e.g., calculation of the sample size to provide the appropriate power for statistical testing.
Secondary
secondary
Secondary. Question to be answered in the study that is of lesser importance than the primary objective.