ResearchStudyStatus

Enum ResearchStudyStatus 

pub enum ResearchStudyStatus {
Show 17 variants Active, ActiveButNotRecruiting, AdministrativelyCompleted, Approved, ClosedToAccrual, ClosedToAccrualAndIntervention, Completed, Disapproved, EnrollingByInvitation, InReview, NotYetRecruiting, OverallStudy, Recruiting, TemporarilyClosedToAccrual, TemporarilyClosedToAccrualAndIntervention, Terminated, Withdrawn,
}
ResearchStudyStatus. Codes that convey the current status of the research study.

FHIR version: 5.0.0.

Variants



Active

active

Active. Study is opened for accrual.



ActiveButNotRecruiting

active-but-not-recruiting

Active, not recruiting. The study is ongoing, and participants are receiving an intervention or being examined, but potential participants are not currently being recruited or enrolled.



AdministrativelyCompleted

administratively-completed

Administratively Completed. Study is completed prematurely and will not resume; patients are no longer examined nor treated.



Approved

approved

Approved. Protocol is approved by the review board.



ClosedToAccrual

closed-to-accrual

Closed to Accrual. Study is closed for accrual; patients can be examined and treated.



ClosedToAccrualAndIntervention

closed-to-accrual-and-intervention

Closed to Accrual and Intervention. Study is closed to accrual and intervention, i.e. the study is closed to enrollment, all study subjects have completed treatment or intervention but are still being followed according to the primary objective of the study.



Completed

completed

Completed. The study closed according to the study plan. There will be no further treatments, interventions or data collection.



Disapproved

disapproved

Disapproved. Protocol was disapproved by the review board.



EnrollingByInvitation

enrolling-by-invitation

Enrolling by invitation. The study is selecting its participants from a population, or group of people, decided on by the researchers in advance. These studies are not open to everyone who meets the eligibility criteria but only to people in that particular population, who are specifically invited to participate.



InReview

in-review

In Review. Protocol is submitted to the review board for approval.



NotYetRecruiting

not-yet-recruiting

Not yet recruiting. The study has not started recruiting participants.



OverallStudy

overall-study

Overall study. Used for documenting the start and end of the overall study, distinct from progress states.



Recruiting

recruiting

Recruiting. The study is currently recruiting participants.



TemporarilyClosedToAccrual

temporarily-closed-to-accrual

Temporarily Closed to Accrual. Study is temporarily closed for accrual; can be potentially resumed in the future; patients can be examined and treated.



TemporarilyClosedToAccrualAndIntervention

temporarily-closed-to-accrual-and-intervention

Temporarily Closed to Accrual and Intervention. Study is temporarily closed for accrual and intervention and potentially can be resumed in the future.



Terminated

terminated

Terminated. The study has stopped early and will not start again. Participants are no longer being examined or treated.



Withdrawn

withdrawn

Withdrawn. Protocol was withdrawn by the lead organization.