pub enum ResponseType {
FatalError,
Ok,
TransientError,
}Expand description
ResponseType. The kind of response to a message.
FHIR version: 5.0.0.
Variants
FatalError
fatal-error
Fatal Error. The message was rejected because of a problem with the content. There is no point in re-sending without change. The response narrative SHALL describe the issue.
Ok
ok
OK. The message was accepted and processed without error.
TransientError
transient-error
Transient Error. Some internal unexpected error occurred - wait and try again. Note - this is usually used for things like database unavailable, which may be expected to resolve, though human intervention may be required.