SampleSecurityStructuralRoles

Enum SampleSecurityStructuralRoles 

pub enum SampleSecurityStructuralRoles {
Show 14 variants BusinessManager, ClaimsAdjudicator, Dentist, Dietician, GeneralMedicine, GeneralNursing, NonRegulatedHealthProfessionals, Pediatrics, Pharmacy, Receptionist, RegulatedHealthProfessionals, Transcriptionist, Veterinarian, _Custom(String),
}
SampleSecurityStructuralRoles. This codeSystem contains example structural roles. In general, two types of roles can be distinguished: structural roles and functional roles. Structural Roles reflect human or organizational categories (hierarchies), and describe prerequisites, feasibilities, or competences for actions. Functional roles are bound to the realization or performance of actions..

FHIR version: 5.0.0.

Variants



BusinessManager

business-manager

Business Manager.



ClaimsAdjudicator

claims-adjudicator

Claims Adjudicator.



Dentist

dentist

Dentist. The specialty relating to the function and diseases of the teeth, mouth, and gums.



Dietician

dietician

Dietician. The health profession concerned with the practical application of diet in the prophylaxis and treatment of disease.



GeneralMedicine

general-medicine

General Medicine. The branch of medicine involving the study and treatment of general diseases or those affecting the internal parts of the body, especially those not usually requiring surgical intervention



GeneralNursing

general-nursing

General Nursing. The branch of healthcare concerned with caring for the sick or injured in any environment.



NonRegulatedHealthProfessionals

non-regulated-health-professionals

Non-Regulated health Professionals. person employed by a healthcare organization who is not a health professional



Pediatrics

pediatrics

Pediatrics. The medical specialty concerned with the study of treatment of children in health and disease during development from birth through adolescence.



Pharmacy

pharmacy

Pharmacy. The branch of medical science that deals with drugs and their uses.



Receptionist

receptionist

Receptionist.



RegulatedHealthProfessionals

regulated-health-professionals

Regulated Health Professionals. A person who is authorized by a national recognized body to be qualified to perform health services



Transcriptionist

transcriptionist

Transcriptionist.



Veterinarian

veterinarian

Veterinarian. The specialty relating to non-human subjects.



_Custom(String)

Custom code value.