pub enum SearchModifierCode {
Show 15 variants
Above,
Below,
CodeText,
Contains,
Exact,
Identifier,
In,
Iterate,
Missing,
Not,
NotIn,
OfType,
Text,
TextAdvanced,
Type,
}Expand description
SearchModifierCode. A supported modifier for a search parameter.
FHIR version: 5.0.0.
Variants
Above
above
Above. The search parameter tests whether the value in a resource subsumes the specified value (is-a, or hierarchical relationships).
Below
below
Below. The search parameter tests whether the value in a resource is subsumed by the specified value (is-a, or hierarchical relationships).
CodeText
code-text
Code Text. Tests whether the textual display value in a resource (e.g., CodeableConcept.text, Coding.display, or Reference.display) matches the supplied parameter value.
Contains
contains
Contains. The search parameter returns resources that include the supplied parameter value anywhere within the field being searched.
Exact
exact
Exact. The search parameter returns resources that have a value that exactly matches the supplied parameter (the whole string, including casing and accents).
Identifier
identifier
Identifier. The search parameter applies to the identifier on the resource, not the reference.
In
in
In. The search parameter is a URI (relative or absolute) that identifies a value set, and the search parameter tests whether the coding is in the specified value set.
Iterate
iterate
Iterate. The search parameter indicates an inclusion directive (_include, _revinclude) that is applied to an included resource instead of the matching resource.
Missing
missing
Missing. The search parameter returns resources that have a value or not.
Not
not
Not. The search parameter returns resources that do not contain a match.
NotIn
not-in
Not In. The search parameter is a URI (relative or absolute) that identifies a value set, and the search parameter tests whether the coding is not in the specified value set.
OfType
of-type
Of Type. The search parameter has the format system|code|value, where the system and code refer to an Identifier.type.coding.system and .code, and match if any of the type codes match. All 3 parts must be present.
Text
text
Text. The search parameter is processed as a string that searches text associated with the code/value - either CodeableConcept.text, Coding.display, Identifier.type.text, or Reference.display.
TextAdvanced
text-advanced
Text Advanced. Tests whether the value in a resource matches the supplied parameter value using advanced text handling that searches text associated with the code/value - e.g., CodeableConcept.text, Coding.display, or Identifier.type.text.
Type
type
Type. The search parameter only applies to the Resource Type specified as a modifier (e.g. the modifier is not actually :type, but :Patient etc.).