pub enum SearchProcessingModeType {
Normal,
Other,
Phonetic,
}Expand description
SearchProcessingModeType. How a search parameter relates to the set of elements returned by evaluating its expression query.
FHIR version: 5.0.0.
Variants
Normal
normal
Normal. The search parameter is derived directly from the selected nodes based on the type definitions.
Other
other
Other. The interpretation of the xpath statement is unknown (and can’t be automated).
Phonetic
phonetic
Phonetic. The search parameter is derived by a phonetic transform from the selected nodes.