pub enum StatisticsCode {
Show 21 variants
N20Percent,
N4Dev,
N4Lower,
N4Upper,
N51,
N52,
N53,
N54,
N80Percent,
Average,
Count,
Kurtosis,
Maximum,
Median,
Minimum,
Regression,
Skew,
StdDev,
Sum,
TotalCount,
Variance,
}Expand description
StatisticsCode. The statistical operation parameter -“statistic” codes.
FHIR version: 5.0.0.
Variants
N20Percent
20-percent
20th Percentile. The 20th Percentile of N measurements over the stated period.
N4Dev
4-dev
Quartile Deviation. The difference between the upper and lower Quartiles is called the Interquartile range. (IQR = Q3-Q1) Quartile deviation or Semi-interquartile range is one-half the difference between the first and the third quartiles.
N4Lower
4-lower
Lower Quartile. The lower Quartile Boundary of N measurements over the stated period.
N4Upper
4-upper
Upper Quartile. The upper Quartile Boundary of N measurements over the stated period.
N51
5-1
1st Quintile. The lowest of four values that divide the N measurements into a frequency distribution of five classes with each containing one fifth of the total population.
N52
5-2
2nd Quintile. The second of four values that divide the N measurements into a frequency distribution of five classes with each containing one fifth of the total population.
N53
5-3
3rd Quintile. The third of four values that divide the N measurements into a frequency distribution of five classes with each containing one fifth of the total population.
N54
5-4
4th Quintile. The fourth of four values that divide the N measurements into a frequency distribution of five classes with each containing one fifth of the total population.
N80Percent
80-percent
80th Percentile. The 80th Percentile of N measurements over the stated period.
Average
average
Average. The mean of N measurements over the stated period.
Count
count
Count. The [number] of valid measurements over the stated period that contributed to the other statistical outputs.
Kurtosis
kurtosis
Kurtosis. Kurtosis is a measure of the “tailedness” of the probability distribution of a real-valued random variable. Source: Wikipedia.
Maximum
maximum
Maximum. The maximum value of N measurements over the stated period.
Median
median
Median. The median of N measurements over the stated period.
Minimum
minimum
Minimum. The minimum value of N measurements over the stated period.
Regression
regression
Regression. Linear regression is an approach for modeling two-dimensional sample points with one independent variable and one dependent variable (conventionally, the x and y coordinates in a Cartesian coordinate system) and finds a linear function (a non-vertical straight line) that, as accurately as possible, predicts the dependent variable values as a function of the independent variables. Source: Wikipedia This Statistic code will return both a gradient and an intercept value.
Skew
skew
Skew. Skewness is a measure of the asymmetry of the probability distribution of a real-valued random variable about its mean. The skewness value can be positive or negative, or even undefined. Source: Wikipedia.
StdDev
std-dev
Standard Deviation. The standard deviation of N measurements over the stated period.
Sum
sum
Sum. The sum of N measurements over the stated period.
TotalCount
total-count
Total Count. The total [number] of valid measurements over the stated period, including observations that were ignored because they did not contain valid result values.
Variance
variance
Variance. The variance of N measurements over the stated period.