pub enum StructureMapSourceListMode {
First,
Last,
NotFirst,
NotLast,
OnlyOne,
}Expand description
StructureMapSourceListMode. If field is a list, how to manage the source.
FHIR version: 5.0.0.
Variants
First
first
First. Only process this rule for the first in the list.
Last
last
Last. Only process this rule for the last in the list.
NotFirst
not_first
All but the first. Process this rule for all but the first.
NotLast
not_last
All but the last. Process this rule for all but the last.
OnlyOne
only_one
Enforce only one. Only process this rule is there is only item.