pub enum SubmitDataUpdateType {
Incremental,
Snapshot,
}Expand description
SubmitDataUpdateType. Concepts for how a measure report consumer and receiver coordinate data exchange updates. The choices are snapshot or incremental updates
FHIR version: 5.0.0.
Variants
Incremental
incremental
Incremental. In contrast to the Snapshot Update, the FHIR Parameters resource used in a Submit Data or the Collect Data scenario contains only the new and updated DEQM and QI Core Profiles since the last transaction. If the Consumer supports incremental updates, the contents of the updated payload updates the previous payload data.
Snapshot
snapshot
Snapshot. In contrast to the Incremental Update, the FHIR Parameters resource used in a Submit Data or the Collect Data scenario contains all the DEQM and QI Core Profiles for each transaction. If the Consumer supports snapshot updates, the contents of the updated payload entirely replaces the previous payload