pub enum SubscriptionNotificationType {
EventNotification,
Handshake,
Heartbeat,
QueryEvent,
QueryStatus,
}Expand description
SubscriptionNotificationType. The type of notification represented by the status message.
FHIR version: 5.0.0.
Variants
EventNotification
event-notification
Event Notification. The status was generated for an event to the subscriber.
Handshake
handshake
Handshake. The status was generated as part of the setup or verification of a communications channel.
Heartbeat
heartbeat
Heartbeat. The status was generated to perform a heartbeat notification to the subscriber.
QueryEvent
query-event
Query Event. The status was generated in response to an event query/request.
QueryStatus
query-status
Query Status. The status was generated in response to a status query/request.