pub enum TaskCode {
Abort,
Approve,
Change,
Fulfill,
Instantiate,
Replace,
Resume,
Suspend,
}Expand description
TaskCode. Codes indicating the type of action that is expected to be performed
FHIR version: 5.0.0.
Variants
Abort
abort
Mark the focal resource as no longer active. Abort, cancel or withdraw the focal resource, as appropriate for the type of resource.
Approve
approve
Activate/approve the focal resource. Take what actions are needed to transition the focus resource from ‘draft’ to ‘active’ or ‘in-progress’, as appropriate for the resource type. This may involve additing additional content, approval, validation, etc.
Change
change
Change the focal resource. Update the focal resource of the owning system to reflect the content specified as the Task.focus
Fulfill
fulfill
Fulfill the focal request. Act to perform the actions described in the focus request. This might result in a ‘more assertive’ request (order for a plan or proposal, filler order for a placer order), but is intend to eventually result in events. The degree of fulfillment requested might be limited by Task.restriction.
Instantiate
instantiate
Instantiate the focal definition. Act to perform the actions defined in the focus definition resource (ActivityDefinition, PlanDefinition, Questionnaire, etc.) For PlanDefinition or ActivityDefinition, this might result in a ‘more assertive’ request (order for a plan or proposal, filler order for a placer order), but is intend to eventually result in events. For Questionnaire, this would result in a QuestionnaireResponse - and possibly resources constructed using data extracted from the response. The degree of fulfillment requested might be limited by Task.restriction.
Replace
replace
Replace the focal resource with the input resource. Replace the focal resource with the specified input resource
Resume
resume
Re-activate the focal resource. Transition the focal resource from ‘suspended’ to ‘active’ or ‘in-progress’ as appropriate for the resource type.
Suspend
suspend
Suspend the focal resource. Transition the focal resource from ‘active’ or ‘in-progress’ to ‘suspended’