pub enum TaskIntent {
Unknown,
_Custom(String),
}Expand description
TaskIntent. Distinguishes whether the task is a proposal, plan or full order.
FHIR version: 5.0.0.
Variants
Unknown
unknown
Unknown. The intent is not known. When dealing with Task, it’s not always known (or relevant) how the task was initiated - i.e. whether it was proposed, planned, ordered or just done spontaneously.
_Custom(String)
Custom code value.