TaskStatus

Enum TaskStatus 

pub enum TaskStatus {
    Accepted,
    Cancelled,
    Completed,
    Draft,
    EnteredInError,
    Failed,
    InProgress,
    OnHold,
    Ready,
    Received,
    Rejected,
    Requested,
}
TaskStatus. The current status of the task.

FHIR version: 5.0.0.

Variants



Accepted

accepted

Accepted. The potential performer has agreed to execute the task but has not yet started work.



Cancelled

cancelled

Cancelled. The task was not completed.



Completed

completed

Completed. The task has been completed.



Draft

draft

Draft. The task is not yet ready to be acted upon.



EnteredInError

entered-in-error

Entered in Error. The task should never have existed and is retained only because of the possibility it may have used.



Failed

failed

Failed. The task was attempted but could not be completed due to some error.



InProgress

in-progress

In Progress. The task has been started but is not yet complete.



OnHold

on-hold

On Hold. The task has been started but work has been paused.



Ready

ready

Ready. The task is ready to be performed, but no action has yet been taken. Used in place of requested/received/accepted/rejected when request assignment and acceptance is a given.



Received

received

Received. A potential performer has claimed ownership of the task and is evaluating whether to perform it.



Rejected

rejected

Rejected. The potential performer who claimed ownership of the task has decided not to execute it prior to performing any action.



Requested

requested

Requested. The task is ready to be acted upon and action is sought.