TaskStatusReason

Enum TaskStatusReason 

pub enum TaskStatusReason {
    EnvironmentalIssue,
    EquipmentIssue,
    Misidentified,
    Missing,
    PersonnelIssue,
}
TaskStatusReason. The current status reason of the task.

FHIR version: 5.0.0.

Variants



EnvironmentalIssue

environmental-issue

Environmental-issue. Something in the environment is preventing task completion.



EquipmentIssue

equipment-issue

Equipment-issue. A piece of equipment necessary for completion of the task is malfunctioning.



Misidentified

misidentified

Misidentified. Something related to the task was misidentified.



Missing

missing

Missing. An item nessary for task completion is missing.



PersonnelIssue

personnel-issue

Personnel-issue. Key personnel necessary for task completion are not present.