TemplateStatusCodeLifeCycle

Enum TemplateStatusCodeLifeCycle 

pub enum TemplateStatusCodeLifeCycle {
    Active,
    Cancelled,
    Draft,
    Pending,
    Rejected,
    Retired,
    Review,
    Terminated,
}
TemplateStatusCodeLifeCycle. Life cycle of the Status Code of a Template Design (Version)

FHIR version: 5.0.0.

Variants



Active

active

active. Design has been deemed fit for the intended purpose and is published by the governance group.



Cancelled

cancelled

Cancelled. A drafted design is determined to be erroneous or not fit for intended purpose and is discontinued before ever being published in an active state.



Draft

draft

Draft. Design is under development (nascent).



Pending

pending

Under pre-publication review. Design is completed and is being reviewed.



Rejected

rejected

Rejected. A previously drafted design is determined to be erroneous or not fit for intended purpose and is discontinued before ever being published for consideration in a pending state.



Retired

retired

retired. A previously active design is discontinued from use. It should no longer be used for future designs, but for historical purposes may be used to process data previously recorded using this design. A newer design may or may not exist. The design is published in the retired state.



Review

review

In Review. Design is active, but is under review. The review may result in a change to the design. The change may necessitate a new version to be created. This in turn may result in the prior version of the template to be retired. Alternatively, the review may result in a change to the design that does not require a new version to be created, or it may result in no change to the design at all.



Terminated

terminated

Terminated. A design is determined to be erroneous or not fit for the intended purpose and should no longer be used, even for historical purposes. No new designs can be developed for this template. The associated template no longer needs to be published, but if published, is shown in the terminated state.