TestReportStatus

Enum TestReportStatus 

pub enum TestReportStatus {
    Completed,
    EnteredInError,
    InProgress,
    Stopped,
    Waiting,
}
TestReportStatus. The current status of the test report.

FHIR version: 5.0.0.

Variants



Completed

completed

Completed. All test operations have completed.



EnteredInError

entered-in-error

Entered In Error. This test report was entered or created in error.



InProgress

in-progress

In Progress. A test operations is currently executing.



Stopped

stopped

Stopped. The test script execution was manually stopped.



Waiting

waiting

Waiting. A test operation is waiting for an external client request.