pub enum TestScriptScopeConformanceType {
Optional,
Required,
Strict,
}Expand description
TestScriptScopeConformanceType. The expectation of whether the test must pass for the system to be considered conformant with the artifact.
FHIR version: 5.0.0.
Variants
Optional
optional
Optional. All tests are expected to pass but non-pass statuses may be allowed.
Required
required
Required. All tests are expected to pass. Warning statuses are permitted. This is the default value.
Strict
strict
Strict. All tests are expected to pass. Warnings are treated as a failure.