pub enum TriggerType {
DataAccessEnded,
DataAccessed,
DataAdded,
DataChanged,
DataModified,
DataRemoved,
NamedEvent,
Periodic,
}Expand description
TriggerType. The type of trigger.
FHIR version: 5.0.0.
Variants
DataAccessEnded
data-access-ended
Data Access Ended. The trigger occurs whenever access to data of a particular type is completed.
DataAccessed
data-accessed
Data Accessed. The trigger occurs whenever data of a particular type is accessed.
DataAdded
data-added
Data Added. The trigger occurs whenever data of a particular type is added.
DataChanged
data-changed
Data Changed. The trigger occurs whenever data of a particular type is changed in any way, either added, modified, or removed.
DataModified
data-modified
Data Updated. The trigger occurs whenever data of a particular type is modified.
DataRemoved
data-removed
Data Removed. The trigger occurs whenever data of a particular type is removed.
NamedEvent
named-event
Named Event. The trigger occurs in response to a specific named event, and no other information about the trigger is specified. Named events are completely pre-coordinated, and the formal semantics of the trigger are not provided.
Periodic
periodic
Periodic. The trigger occurs at a specific time or periodically as described by a timing or schedule. A periodic event cannot have any data elements, but may have a name assigned as a shorthand for the event.