pub enum Use {
Claim,
Preauthorization,
Predetermination,
}Expand description
Use. The purpose of the Claim: predetermination, preauthorization, claim.
FHIR version: 5.0.0.
Variants
Claim
claim
Claim. The treatment is complete and this represents a Claim for the services.
preauthorization
Preauthorization. The treatment is proposed and this represents a Pre-authorization for the services.
Predetermination
predetermination
Predetermination. The treatment is proposed and this represents a Pre-determination for the services.