pub enum VersionAlgorithm {
Alpha,
Date,
Integer,
Natural,
Semver,
}Expand description
VersionAlgorithm. Indicates the mechanism used to compare versions to determine which is more current.
FHIR version: 5.0.0.
Variants
Alpha
alpha
Alphabetical. Simple alphabetic sort on a case-insensitive and accent-insensitive basis. (Sorting of different cases or accented versions of a character is indeterminate)
Date
date
Date. Versions are expressed as an ISO date/time syntax (including syntaxes with only portions of a date)
Integer
integer
Integer. Versions are integers and ordered numerically
Natural
natural
Natural. Sorted according to the algorithm defined here: naturalordersort.org
Semver
semver
SemVer. Uses the semantic versioning scheme as defined in semver.org.