pub struct CodeSystemConceptBuilder { /* private fields */ }Expand description
Builder for CodeSystemConcept.
Implementations
Sourceimpl CodeSystemConceptBuilder
impl CodeSystemConceptBuilder
Sourcepub fn id(self, value: String) -> Self
pub fn id(self, value: String) -> Self
Unique id for inter-element referencing
Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
Sourcepub fn extension(self, value: Vec<Extension>) -> Self
pub fn extension(self, value: Vec<Extension>) -> Self
Additional content defined by implementations
May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
There can be no stigma associated with the use of extensions by any application, project, or standard - regardless of the institution or jurisdiction that uses or defines the extensions. The use of extensions is what allows the FHIR specification to retain a core level of simplicity for everyone.
Sourcepub fn modifier_extension(self, value: Vec<Extension>) -> Self
pub fn modifier_extension(self, value: Vec<Extension>) -> Self
Extensions that cannot be ignored even if unrecognized
May be used to represent additional information that is not part of the basic definition of the element and that modifies the understanding of the element in which it is contained and/or the understanding of the containing element’s descendants. Usually modifier elements provide negation or qualification. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension. Applications processing a resource are required to check for modifier extensions.
Modifier extensions SHALL NOT change the meaning of any elements on Resource or DomainResource (including cannot change the meaning of modifierExtension itself).
There can be no stigma associated with the use of extensions by any application, project, or standard - regardless of the institution or jurisdiction that uses or defines the extensions. The use of extensions is what allows the FHIR specification to retain a core level of simplicity for everyone.
Sourcepub fn code(self, value: String) -> Self
pub fn code(self, value: String) -> Self
Code that identifies concept
A code - a text symbol - that uniquely identifies the concept within the code system.
Sourcepub fn code_ext(self, value: FieldExtension) -> Self
pub fn code_ext(self, value: FieldExtension) -> Self
Extension field.
Sourcepub fn display(self, value: String) -> Self
pub fn display(self, value: String) -> Self
Text to display to the user
A human readable string that is the recommended default way to present this concept to a user.
Sourcepub fn display_ext(self, value: FieldExtension) -> Self
pub fn display_ext(self, value: FieldExtension) -> Self
Extension field.
Sourcepub fn definition(self, value: String) -> Self
pub fn definition(self, value: String) -> Self
Formal definition
The formal definition of the concept. The code system resource does not make formal definitions required, because of the prevalence of legacy systems. However, they are highly recommended, as without them there is no formal meaning associated with the concept.
Sourcepub fn definition_ext(self, value: FieldExtension) -> Self
pub fn definition_ext(self, value: FieldExtension) -> Self
Extension field.
Sourcepub fn designation(
self,
value: Vec<Option<CodeSystemConceptDesignation>>,
) -> Self
pub fn designation( self, value: Vec<Option<CodeSystemConceptDesignation>>, ) -> Self
Additional representations for the concept
Additional representations for the concept - other languages, aliases, specialized purposes, used for particular purposes, etc.
Concepts have both a textdisplay and an array of textdesignation. The display is equivalent to a special designation with an implied textdesignation.use of “primary code” and a language equal to the Resource Language.
Sourcepub fn designation_ext(self, value: Vec<Option<FieldExtension>>) -> Self
pub fn designation_ext(self, value: Vec<Option<FieldExtension>>) -> Self
Extension field.
Sourcepub fn property(self, value: Vec<Option<CodeSystemConceptProperty>>) -> Self
pub fn property(self, value: Vec<Option<CodeSystemConceptProperty>>) -> Self
Property value for the concept
A property value for this concept.
Sourcepub fn property_ext(self, value: Vec<Option<FieldExtension>>) -> Self
pub fn property_ext(self, value: Vec<Option<FieldExtension>>) -> Self
Extension field.
Sourcepub fn concept(self, value: Vec<Option<CodeSystemConcept>>) -> Self
pub fn concept(self, value: Vec<Option<CodeSystemConcept>>) -> Self
Child Concepts (is-a/contains/categorizes)
Defines children of a concept to produce a hierarchy of concepts. The nature of the relationships is variable (is-a/contains/categorizes) - see hierarchyMeaning.
Sourcepub fn concept_ext(self, value: Vec<Option<FieldExtension>>) -> Self
pub fn concept_ext(self, value: Vec<Option<FieldExtension>>) -> Self
Extension field.