CodingBuilder

Struct CodingBuilder 

pub struct CodingBuilder { /* private fields */ }
Builder for CodingInner.

Implementations

Source

impl CodingBuilder

pub fn id(self, value: String) -> Self

Unique id for inter-element referencing

Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.

pub fn extension(self, value: Vec<Extension>) -> Self

Additional content defined by implementations

May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and managable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.

There can be no stigma associated with the use of extensions by any application, project, or standard - regardless of the institution or jurisdiction that uses or defines the extensions. The use of extensions is what allows the FHIR specification to retain a core level of simplicity for everyone.

pub fn system(self, value: String) -> Self

Identity of the terminology system

The identification of the code system that defines the meaning of the symbol in the code.

The URI may be an OID (urn:oid:…) or a UUID (urn:uuid:…). OIDs and UUIDs SHALL be references to the HL7 OID registry. Otherwise, the URI should come from HL7’s list of FHIR defined special URIs or it should be an absolute reference to some definition that establishes the system clearly and unambiguously.

pub fn system_ext(self, value: FieldExtension) -> Self

Extension field.

pub fn version(self, value: String) -> Self

Version of the system - if relevant

The version of the code system which was used when choosing this code. Note that a well-maintained code system does not need the version reported, because the meaning of codes is consistent across versions. However this cannot consistently be assured, and when the meaning is not guaranteed to be consistent, the version SHOULD be exchanged.

Where the terminology does not clearly define what string should be used to identify code system versions, the recommendation is to use the date (expressed in FHIR date format) on which that version was officially published as the version date.

pub fn version_ext(self, value: FieldExtension) -> Self

Extension field.

pub fn code(self, value: String) -> Self

Symbol in syntax defined by the system

A symbol in syntax defined by the system. The symbol may be a predefined code or an expression in a syntax defined by the coding system (e.g. post-coordination).

pub fn code_ext(self, value: FieldExtension) -> Self

Extension field.

pub fn display(self, value: String) -> Self

Representation defined by the system

A representation of the meaning of the code in the system, following the rules of the system.

pub fn display_ext(self, value: FieldExtension) -> Self

Extension field.

pub fn user_selected(self, value: bool) -> Self

If this coding was chosen directly by the user

Indicates that this coding was chosen by a user directly - e.g. off a pick list of available items (codes or displays).

Amongst a set of alternatives, a directly chosen code is the most appropriate starting point for new translations. There is some ambiguity about what exactly ‘directly chosen’ implies, and trading partner agreement may be needed to clarify the use of this element and its consequences more completely.

pub fn user_selected_ext(self, value: FieldExtension) -> Self

Extension field.

pub fn build_inner(self) -> Result<CodingInner, BuilderError>

Builds a new CodingInner.

Errors

If a required field has not been initialized.

Source

impl CodingBuilder

pub fn build(self) -> Result<Coding, BuilderError>

Finalize building Coding.