pub enum ActionParticipantFunction {
Author,
Performer,
Reviewer,
Witness,
}Expand description
ActionParticipantFunction. The function performed by the participant for the action.
FHIR version: 5.0.0.
Variants
Author
author
Author. The participant is the author of the result of the action.
Performer
performer
Performer. The participant is the performer of the action.
Reviewer
reviewer
Reviewer. The participant is reviewing the result of the action.
Witness
witness
Witness. The participant is a witness to the action being performed.