pub enum CodeSystemContentMode {
Complete,
Example,
Fragment,
NotPresent,
Supplement,
}Expand description
CodeSystemContentMode. The extent of the content of the code system (the concepts and codes it defines) are represented in a code system resource.
FHIR version: 5.0.0.
Variants
Complete
complete
Complete. All the concepts defined by the code system are included in the code system resource.
Example
example
Example. A subset of the valid externally defined concepts are included in the code system resource. There is no specific purpose or documented intent other than for illustrative purposes.
Fragment
fragment
Fragment. A subset of the code system concepts are included in the code system resource. This is a curated subset released for a specific purpose under the governance of the code system steward, and that the intent, bounds and consequences of the fragmentation are clearly defined in the fragment or the code system documentation. Fragments are also known as partitions.
NotPresent
not-present
Not Present. None of the concepts defined by the code system are included in the code system resource.
Supplement
supplement
Supplement. The resource doesn’t define any new concepts; it just provides additional designations and properties to another code system.