pub enum ContactPointSystem {
Email,
Fax,
Other,
Pager,
Phone,
Sms,
Url,
}Expand description
ContactPointSystem. Telecommunications form for contact point.
FHIR version: 5.0.0.
Variants
Email. The value is an email address.
Fax
fax
Fax. The value is a fax machine. Use of full international numbers starting with + is recommended to enable automatic dialing support but not required.
Other
other
Other. A contact that is not a phone, fax, page or email address and is not expressible as a URL. E.g. Internal mail address. This SHOULD NOT be used for contacts that are expressible as a URL (e.g. Skype, Twitter, Facebook, etc.) Extensions may be used to distinguish “other” contact types.
Pager
pager
Pager. The value is a pager number. These may be local pager numbers that are only usable on a particular pager system.
Phone
phone
Phone. The value is a telephone number used for voice calls. Use of full international numbers starting with + is recommended to enable automatic dialing support but not required.
Sms
sms
SMS. A contact that can be used for sending a sms message (e.g. mobile phones, some landlines).
Url
url
URL. A contact that is not a phone, fax, pager or email address and is expressed as a URL. This is intended for various institutional or personal contacts including web sites, blogs, Skype, Twitter, Facebook, etc. Do not use for email addresses.