pub enum DefinitionMethod {
Mean,
MeanOfMean,
MeanOfMedian,
Median,
MedianOfMean,
MedianOfMedian,
NonSystematicAssessment,
SystematicAssessment,
}Expand description
DefinitionMethod. The method used to define, describe, or determine a characteristic value.
FHIR version: 5.0.0.
Variants
Mean
mean
Mean. Aggregated using mean of observed values.
MeanOfMean
mean-of-mean
Mean of Means. Aggregated using mean of means (e.g. study mean values).
MeanOfMedian
mean-of-median
Mean of Medians. Aggregated using mean of medians (e.g. study median values).
Median
median
Median. Aggregated using median of observed values.
MedianOfMean
median-of-mean
Median of Means. Aggregated using median of means (e.g. study mean values).
MedianOfMedian
median-of-median
Median of Medians. Aggregated using median of medians (e.g. study median values).
NonSystematicAssessment
non-systematic-assessment
Non-Systematic Assessment. Any non-systematic method for determining whether or not adverse events have occurred, such as self-reporting by participants or occasional assessment/testing
SystematicAssessment
systematic-assessment
Systematic Assessment. Any method of routinely determining whether or not specific outcomes (e.g. adverse events) have occurred, for example through a standard questionnaire, regular investigator assessment, regular laboratory testing, or other method