pub enum DetectedIssueSeverity {
High,
Low,
Moderate,
}Expand description
DetectedIssueSeverity. Indicates the potential degree of impact of the identified issue on the patient.
FHIR version: 5.0.0.
Variants
High
high
High. Indicates the issue may be life-threatening or has the potential to cause permanent injury.
Low
low
Low. Indicates the issue may result in some adverse consequences but is unlikely to substantially affect the situation of the subject.
Moderate
moderate
Moderate. Indicates the issue may result in noticeable adverse consequences but is unlikely to be life-threatening or cause permanent injury.