pub enum EventStatus {
Completed,
EnteredInError,
InProgress,
NotDone,
OnHold,
Preparation,
Stopped,
Unknown,
}Expand description
EventStatus. Codes identifying the lifecycle stage of an event.
FHIR version: 5.0.0.
Variants
Completed
completed
Completed. The event has now concluded.
EnteredInError
entered-in-error
Entered in Error. This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be “stopped” rather than “entered-in-error”.).
InProgress
in-progress
In Progress. The event is currently occurring.
NotDone
not-done
Not Done. The event was terminated prior to any activity beyond preparation. I.e. The ‘main’ activity has not yet begun. The boundary between preparatory and the ‘main’ activity is context-specific.
OnHold
on-hold
On Hold. The event has been temporarily stopped but is expected to resume in the future.
Preparation
preparation
Preparation. The core event has not started yet, but some staging activities have begun (e.g. surgical suite preparation). Preparation stages may be tracked for billing purposes.
Stopped
stopped
Stopped. The event was terminated prior to the full completion of the intended activity but after at least some of the ‘main’ activity (beyond preparation) has occurred.
Unknown
unknown
Unknown. The authoring/source system does not know which of the status values currently applies for this event. Note: This concept is not to be used for “other” - one of the listed statuses is presumed to apply, but the authoring/source system does not know which.