pub enum IdentifierUse {
Official,
Old,
Secondary,
Temp,
Usual,
}Expand description
IdentifierUse. Identifies the purpose for this identifier, if known .
FHIR version: 5.0.0.
Variants
Official
official
Official. The identifier considered to be most trusted for the identification of this item. Sometimes also known as “primary” and “main”. The determination of “official” is subjective and implementation guides often provide additional guidelines for use.
Old
old
Old. The identifier id no longer considered valid, but may be relevant for search purposes. E.g. Changes to identifier schemes, account merges, etc.
Secondary
secondary
Secondary. An identifier that was assigned in secondary use - it serves to identify the object in a relative context, but cannot be consistently assigned to the same object again in a different context.
Temp
temp
Temp. A temporary identifier.
Usual
usual
Usual. The identifier recommended for display and use in real-world interactions which should be used when such identifier is different from the “official” identifier.