pub enum ImagingStudyStatus {
Available,
Cancelled,
EnteredInError,
Registered,
Unknown,
}Expand description
ImagingStudyStatus. The status of the ImagingStudy.
FHIR version: 5.0.0.
Variants
Available
available
Available. At least one instance has been associated with this imaging study.
Cancelled
cancelled
Cancelled. The imaging study is unavailable because the imaging study was not started or not completed (also sometimes called “aborted”).
EnteredInError
entered-in-error
Entered in Error. The imaging study has been withdrawn following a previous final release. This electronic record should never have existed, though it is possible that real-world decisions were based on it. (If real-world activity has occurred, the status should be “cancelled” rather than “entered-in-error”.).
Registered
registered
Registered. The existence of the imaging study is registered, but there is nothing yet available.
Unknown
unknown
Unknown. The system does not know which of the status values currently applies for this request. Note: This concept is not to be used for “other” - one of the listed statuses is presumed to apply, it’s just not known which one.