pub enum InventoryCountType {
Difference,
Snapshot,
}Expand description
InventoryCountType. The type of count.
FHIR version: 5.0.0.
Variants
Difference
difference
Difference. The inventory report is about the difference between a previous count and a current count, i.e. it represents the items that have been added/subtracted from inventory.
Snapshot
snapshot
Snapshot. The inventory report is a current absolute snapshot, i.e. it represents the quantities at hand.