pub enum LinkRelationTypes {
Show 120 variants
P3Pv1,
About,
Acl,
Alternate,
Amphtml,
Appendix,
AppleTouchIcon,
AppleTouchStartupImage,
Archives,
Author,
BlockedBy,
Bookmark,
Canonical,
Chapter,
CiteAs,
Collection,
Contents,
ConvertedFrom,
Copyright,
CreateForm,
Current,
Describedby,
Describes,
Disclosure,
DnsPrefetch,
Duplicate,
Edit,
EditForm,
EditMedia,
Enclosure,
External,
First,
Glossary,
Help,
Hosts,
Hub,
Icon,
Index,
IntervalAfter,
IntervalBefore,
IntervalContains,
IntervalDisjoint,
IntervalDuring,
IntervalEquals,
IntervalFinishedBy,
IntervalFinishes,
IntervalIn,
IntervalMeets,
IntervalMetBy,
IntervalOverlappedBy,
IntervalOverlaps,
IntervalStartedBy,
IntervalStarts,
Item,
Last,
LatestVersion,
License,
Linkset,
Lrdd,
Manifest,
MaskIcon,
MediaFeed,
Memento,
Micropub,
Modulepreload,
Monitor,
MonitorGroup,
Next,
NextArchive,
Nofollow,
Noopener,
Noreferrer,
Opener,
Openid2LocalId,
Openid2Provider,
Original,
Payment,
Pingback,
Preconnect,
PredecessorVersion,
Prefetch,
Preload,
Prerender,
Prev,
PrevArchive,
Preview,
Previous,
PrivacyPolicy,
Profile,
Publication,
Related,
Replies,
Restconf,
Ruleinput,
Search,
Section,
_Self,
Service,
ServiceDesc,
ServiceDoc,
ServiceMeta,
Sponsored,
Start,
Status,
Stylesheet,
Subsection,
SuccessorVersion,
Sunset,
Tag,
TermsOfService,
Timegate,
Timemap,
Type,
Ugc,
Up,
VersionHistory,
Via,
Webmention,
WorkingCopy,
WorkingCopyOf,
}Expand description
LinkRelationTypes. Link Relation Types defined at https://www.iana.org/assignments/link-relations/link-relations.xhtml#link-relations-1
FHIR version: 5.0.0.
Variants
P3Pv1
P3Pv1
Refers to a P3P privacy policy for the context.. Refers to a P3P privacy policy for the context.
About
about
Refers to a resource that is the subject of the link’s context.. Refers to a resource that is the subject of the link’s context.
Acl
acl
Asserts that the link target provides an access control description for the link context.. Asserts that the link target provides an access control description for the link context.
Alternate
alternate
Refers to a substitute for this context. Refers to a substitute for this context
Amphtml
amphtml
Used to reference alternative content that uses the AMP profile of the HTML format.. Used to reference alternative content that uses the AMP profile of the HTML format.
Appendix
appendix
Refers to an appendix.. Refers to an appendix.
AppleTouchIcon
apple-touch-icon
Refers to an icon for the context. Synonym for icon.. Refers to an icon for the context. Synonym for icon.
AppleTouchStartupImage
apple-touch-startup-image
Refers to a launch screen for the context.. Refers to a launch screen for the context.
Archives
archives
Refers to a collection of records, documents, or other materials of historical interest.. Refers to a collection of records, documents, or other materials of historical interest.
Author
author
Refers to the context’s author.. Refers to the context’s author.
BlockedBy
blocked-by
Identifies the entity that blocks access to a resource following receipt of a legal demand.. Identifies the entity that blocks access to a resource following receipt of a legal demand.
Bookmark
bookmark
Gives a permanent link to use for bookmarking purposes.. Gives a permanent link to use for bookmarking purposes.
Canonical
canonical
Designates the preferred version of a resource (the IRI and its contents).. Designates the preferred version of a resource (the IRI and its contents).
Chapter
chapter
Refers to a chapter in a collection of resources.. Refers to a chapter in a collection of resources.
CiteAs
cite-as
Indicates that the link target is preferred over the link context for the purpose of permanent citation.. Indicates that the link target is preferred over the link context for the purpose of permanent citation.
Collection
collection
The target IRI points to a resource which represents the collection resource for the context IRI.. The target IRI points to a resource which represents the collection resource for the context IRI.
Contents
contents
Refers to a table of contents.. Refers to a table of contents.
ConvertedFrom
convertedFrom
The document linked to was later converted to the document that contains this link relation. For example, an RFC can have a link to the Internet-Draft that became the RFC; in that case, the link relation would be “convertedFrom”.. The document linked to was later converted to the document that contains this link relation. For example, an RFC can have a link to the Internet-Draft that became the RFC; in that case, the link relation would be “convertedFrom”.
Copyright
copyright
Refers to a copyright statement that applies to the link’s context.. Refers to a copyright statement that applies to the link’s context.
CreateForm
create-form
The target IRI points to a resource where a submission form can be obtained.. The target IRI points to a resource where a submission form can be obtained.
Current
current
Refers to a resource containing the most recent item(s) in a collection of resources.. Refers to a resource containing the most recent item(s) in a collection of resources.
Describedby
describedby
Refers to a resource providing information about the link’s context.. Refers to a resource providing information about the link’s context.
Describes
describes
The relationship A ‘describes’ B asserts that resource A provides a description of resource B. There are no constraints on the format or representation of either A or B, neither are there any further constraints on either resource.. The relationship A ‘describes’ B asserts that resource A provides a description of resource B. There are no constraints on the format or representation of either A or B, neither are there any further constraints on either resource.
Disclosure
disclosure
Refers to a list of patent disclosures made with respect to material for which ‘disclosure’ relation is specified.. Refers to a list of patent disclosures made with respect to material for which ‘disclosure’ relation is specified.
DnsPrefetch
dns-prefetch
Used to indicate an origin that will be used to fetch required resources for the link context, and that the user agent ought to resolve as early as possible.. Used to indicate an origin that will be used to fetch required resources for the link context, and that the user agent ought to resolve as early as possible.
Duplicate
duplicate
Refers to a resource whose available representations are byte-for-byte identical with the corresponding representations of the context IRI.. Refers to a resource whose available representations are byte-for-byte identical with the corresponding representations of the context IRI.
Edit
edit
Refers to a resource that can be used to edit the link’s context.. Refers to a resource that can be used to edit the link’s context.
EditForm
edit-form
The target IRI points to a resource where a submission form for editing associated resource can be obtained.. The target IRI points to a resource where a submission form for editing associated resource can be obtained.
EditMedia
edit-media
Refers to a resource that can be used to edit media associated with the link’s context.. Refers to a resource that can be used to edit media associated with the link’s context.
Enclosure
enclosure
Identifies a related resource that is potentially large and might require special handling.. Identifies a related resource that is potentially large and might require special handling.
External
external
Refers to a resource that is not part of the same site as the current context.. Refers to a resource that is not part of the same site as the current context.
First
first
An IRI that refers to the furthest preceding resource in a series of resources.. An IRI that refers to the furthest preceding resource in a series of resources.
Glossary
glossary
Refers to a glossary of terms.. Refers to a glossary of terms.
Help
help
Refers to context-sensitive help.. Refers to context-sensitive help.
Hosts
hosts
Refers to a resource hosted by the server indicated by the link context.. Refers to a resource hosted by the server indicated by the link context.
Hub
hub
Refers to a hub that enables registration for notification of updates to the context.. Refers to a hub that enables registration for notification of updates to the context.
Icon
icon
Refers to an icon representing the link’s context.. Refers to an icon representing the link’s context.
Index
index
Refers to an index.. Refers to an index.
IntervalAfter
intervalAfter
refers to a resource associated with a time interval that ends before the beginning of the time interval associated with the context resource. refers to a resource associated with a time interval that ends before the beginning of the time interval associated with the context resource
IntervalBefore
intervalBefore
refers to a resource associated with a time interval that begins after the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins after the end of the time interval associated with the context resource
IntervalContains
intervalContains
refers to a resource associated with a time interval that begins after the beginning of the time interval associated with the context resource, and ends before the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins after the beginning of the time interval associated with the context resource, and ends before the end of the time interval associated with the context resource
IntervalDisjoint
intervalDisjoint
refers to a resource associated with a time interval that begins after the end of the time interval associated with the context resource, or ends before the beginning of the time interval associated with the context resource. refers to a resource associated with a time interval that begins after the end of the time interval associated with the context resource, or ends before the beginning of the time interval associated with the context resource
IntervalDuring
intervalDuring
refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource
IntervalEquals
intervalEquals
refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource. refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource
IntervalFinishedBy
intervalFinishedBy
refers to a resource associated with a time interval that begins after the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins after the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource
IntervalFinishes
intervalFinishes
refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and whose end coincides with the end of the time interval associated with the context resource
IntervalIn
intervalIn
refers to a resource associated with a time interval that begins before or is coincident with the beginning of the time interval associated with the context resource, and ends after or is coincident with the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins before or is coincident with the beginning of the time interval associated with the context resource, and ends after or is coincident with the end of the time interval associated with the context resource
IntervalMeets
intervalMeets
refers to a resource associated with a time interval whose beginning coincides with the end of the time interval associated with the context resource. refers to a resource associated with a time interval whose beginning coincides with the end of the time interval associated with the context resource
IntervalMetBy
intervalMetBy
refers to a resource associated with a time interval whose end coincides with the beginning of the time interval associated with the context resource. refers to a resource associated with a time interval whose end coincides with the beginning of the time interval associated with the context resource
IntervalOverlappedBy
intervalOverlappedBy
refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and ends after the beginning of the time interval associated with the context resource. refers to a resource associated with a time interval that begins before the beginning of the time interval associated with the context resource, and ends after the beginning of the time interval associated with the context resource
IntervalOverlaps
intervalOverlaps
refers to a resource associated with a time interval that begins before the end of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource. refers to a resource associated with a time interval that begins before the end of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource
IntervalStartedBy
intervalStartedBy
refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and ends before the end of the time interval associated with the context resource. refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and ends before the end of the time interval associated with the context resource
IntervalStarts
intervalStarts
refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource. refers to a resource associated with a time interval whose beginning coincides with the beginning of the time interval associated with the context resource, and ends after the end of the time interval associated with the context resource
Item
item
The target IRI points to a resource that is a member of the collection represented by the context IRI.. The target IRI points to a resource that is a member of the collection represented by the context IRI.
Last
last
An IRI that refers to the furthest following resource in a series of resources.. An IRI that refers to the furthest following resource in a series of resources.
LatestVersion
latest-version
Points to a resource containing the latest (e.g., current) version of the context.. Points to a resource containing the latest (e.g., current) version of the context.
License
license
Refers to a license associated with this context.. Refers to a license associated with this context.
Linkset
linkset
The link target of a link with the “linkset” relation type provides a set of links, including links in which the link context of the link participates. . The link target of a link with the “linkset” relation type provides a set of links, including links in which the link context of the link participates.
Lrdd
lrdd
Refers to further information about the link’s context, expressed as a LRDD (“Link-based Resource Descriptor Document”) resource. See for information about processing this relation type in host-meta documents. When used elsewhere, it refers to additional links and other metadata. Multiple instances indicate additional LRDD resources. LRDD resources MUST have an “application/xrd+xml” representation, and MAY have others.. Refers to further information about the link’s context, expressed as a LRDD (“Link-based Resource Descriptor Document”) resource. See for information about processing this relation type in host-meta documents. When used elsewhere, it refers to additional links and other metadata. Multiple instances indicate additional LRDD resources. LRDD resources MUST have an “application/xrd+xml” representation, and MAY have others.
Manifest
manifest
Links to a manifest file for the context.. Links to a manifest file for the context.
MaskIcon
mask-icon
Refers to a mask that can be applied to the icon for the context.. Refers to a mask that can be applied to the icon for the context.
MediaFeed
media-feed
Refers to a feed of personalised media recommendations relevant to the link context.. Refers to a feed of personalised media recommendations relevant to the link context.
Memento
memento
The Target IRI points to a Memento, a fixed resource that will not change state anymore.. The Target IRI points to a Memento, a fixed resource that will not change state anymore.
Micropub
micropub
Links to the context’s Micropub endpoint.. Links to the context’s Micropub endpoint.
Modulepreload
modulepreload
Refers to a module that the user agent is to preemptively fetch and store for use in the current context.. Refers to a module that the user agent is to preemptively fetch and store for use in the current context.
Monitor
monitor
Refers to a resource that can be used to monitor changes in an HTTP resource. . Refers to a resource that can be used to monitor changes in an HTTP resource.
MonitorGroup
monitor-group
Refers to a resource that can be used to monitor changes in a specified group of HTTP resources. . Refers to a resource that can be used to monitor changes in a specified group of HTTP resources.
Next
next
Indicates that the link’s context is a part of a series, and that the next in the series is the link target. . Indicates that the link’s context is a part of a series, and that the next in the series is the link target.
NextArchive
next-archive
Refers to the immediately following archive resource.. Refers to the immediately following archive resource.
Nofollow
nofollow
Indicates that the context’s original author or publisher does not endorse the link target.. Indicates that the context’s original author or publisher does not endorse the link target.
Noopener
noopener
Indicates that any newly created top-level browsing context which results from following the link will not be an auxiliary browsing context.. Indicates that any newly created top-level browsing context which results from following the link will not be an auxiliary browsing context.
Noreferrer
noreferrer
Indicates that no referrer information is to be leaked when following the link.. Indicates that no referrer information is to be leaked when following the link.
Opener
opener
Indicates that any newly created top-level browsing context which results from following the link will be an auxiliary browsing context.. Indicates that any newly created top-level browsing context which results from following the link will be an auxiliary browsing context.
Openid2LocalId
openid2.local_id
Refers to an OpenID Authentication server on which the context relies for an assertion that the end user controls an Identifier.. Refers to an OpenID Authentication server on which the context relies for an assertion that the end user controls an Identifier.
Openid2Provider
openid2.provider
Refers to a resource which accepts OpenID Authentication protocol messages for the context.. Refers to a resource which accepts OpenID Authentication protocol messages for the context.
Original
original
The Target IRI points to an Original Resource.. The Target IRI points to an Original Resource.
Payment
payment
Indicates a resource where payment is accepted.. Indicates a resource where payment is accepted.
Pingback
pingback
Gives the address of the pingback resource for the link context.. Gives the address of the pingback resource for the link context.
Preconnect
preconnect
Used to indicate an origin that will be used to fetch required resources for the link context. Initiating an early connection, which includes the DNS lookup, TCP handshake, and optional TLS negotiation, allows the user agent to mask the high latency costs of establishing a connection.. Used to indicate an origin that will be used to fetch required resources for the link context. Initiating an early connection, which includes the DNS lookup, TCP handshake, and optional TLS negotiation, allows the user agent to mask the high latency costs of establishing a connection.
PredecessorVersion
predecessor-version
Points to a resource containing the predecessor version in the version history. . Points to a resource containing the predecessor version in the version history.
Prefetch
prefetch
The prefetch link relation type is used to identify a resource that might be required by the next navigation from the link context, and that the user agent ought to fetch, such that the user agent can deliver a faster response once the resource is requested in the future.. The prefetch link relation type is used to identify a resource that might be required by the next navigation from the link context, and that the user agent ought to fetch, such that the user agent can deliver a faster response once the resource is requested in the future.
Preload
preload
Refers to a resource that should be loaded early in the processing of the link’s context, without blocking rendering.. Refers to a resource that should be loaded early in the processing of the link’s context, without blocking rendering.
Prerender
prerender
Used to identify a resource that might be required by the next navigation from the link context, and that the user agent ought to fetch and execute, such that the user agent can deliver a faster response once the resource is requested in the future.. Used to identify a resource that might be required by the next navigation from the link context, and that the user agent ought to fetch and execute, such that the user agent can deliver a faster response once the resource is requested in the future.
Prev
prev
Indicates that the link’s context is a part of a series, and that the previous in the series is the link target. . Indicates that the link’s context is a part of a series, and that the previous in the series is the link target.
PrevArchive
prev-archive
Refers to the immediately preceding archive resource.. Refers to the immediately preceding archive resource.
Preview
preview
Refers to a resource that provides a preview of the link’s context.. Refers to a resource that provides a preview of the link’s context.
Previous
previous
Refers to the previous resource in an ordered series of resources. Synonym for “prev”.. Refers to the previous resource in an ordered series of resources. Synonym for “prev”.
PrivacyPolicy
privacy-policy
Refers to a privacy policy associated with the link’s context.. Refers to a privacy policy associated with the link’s context.
Profile
profile
Identifying that a resource representation conforms to a certain profile, without affecting the non-profile semantics of the resource representation.. Identifying that a resource representation conforms to a certain profile, without affecting the non-profile semantics of the resource representation.
Publication
publication
Links to a publication manifest. A manifest represents structured information about a publication, such as informative metadata, a list of resources, and a default reading order.. Links to a publication manifest. A manifest represents structured information about a publication, such as informative metadata, a list of resources, and a default reading order.
Related
related
Identifies a related resource.. Identifies a related resource.
Replies
replies
Identifies a resource that is a reply to the context of the link. . Identifies a resource that is a reply to the context of the link.
Restconf
restconf
Identifies the root of RESTCONF API as configured on this HTTP server. The “restconf” relation defines the root of the API defined in RFC8040. Subsequent revisions of RESTCONF will use alternate relation values to support protocol versioning.. Identifies the root of RESTCONF API as configured on this HTTP server. The “restconf” relation defines the root of the API defined in RFC8040. Subsequent revisions of RESTCONF will use alternate relation values to support protocol versioning.
Ruleinput
ruleinput
The resource identified by the link target provides an input value to an instance of a rule, where the resource which represents the rule instance is identified by the link context. . The resource identified by the link target provides an input value to an instance of a rule, where the resource which represents the rule instance is identified by the link context.
Search
search
Refers to a resource that can be used to search through the link’s context and related resources.. Refers to a resource that can be used to search through the link’s context and related resources.
Section
section
Refers to a section in a collection of resources.. Refers to a section in a collection of resources.
_Self
self
Conveys an identifier for the link’s context. . Conveys an identifier for the link’s context.
Service
service
Indicates a URI that can be used to retrieve a service document.. Indicates a URI that can be used to retrieve a service document.
ServiceDesc
service-desc
Identifies service description for the context that is primarily intended for consumption by machines.. Identifies service description for the context that is primarily intended for consumption by machines.
ServiceDoc
service-doc
Identifies service documentation for the context that is primarily intended for human consumption.. Identifies service documentation for the context that is primarily intended for human consumption.
ServiceMeta
service-meta
Identifies general metadata for the context that is primarily intended for consumption by machines.. Identifies general metadata for the context that is primarily intended for consumption by machines.
Sponsored
sponsored
Refers to a resource that is within a context that is sponsored (such as advertising or another compensation agreement).. Refers to a resource that is within a context that is sponsored (such as advertising or another compensation agreement).
Start
start
Refers to the first resource in a collection of resources.. Refers to the first resource in a collection of resources.
Status
status
Identifies a resource that represents the context’s status.. Identifies a resource that represents the context’s status.
Stylesheet
stylesheet
Refers to a stylesheet.. Refers to a stylesheet.
Subsection
subsection
Refers to a resource serving as a subsection in a collection of resources.. Refers to a resource serving as a subsection in a collection of resources.
SuccessorVersion
successor-version
Points to a resource containing the successor version in the version history. . Points to a resource containing the successor version in the version history.
Sunset
sunset
Identifies a resource that provides information about the context’s retirement policy. . Identifies a resource that provides information about the context’s retirement policy.
Tag
tag
Gives a tag (identified by the given address) that applies to the current document. . Gives a tag (identified by the given address) that applies to the current document.
TermsOfService
terms-of-service
Refers to the terms of service associated with the link’s context.. Refers to the terms of service associated with the link’s context.
Timegate
timegate
The Target IRI points to a TimeGate for an Original Resource.. The Target IRI points to a TimeGate for an Original Resource.
Timemap
timemap
The Target IRI points to a TimeMap for an Original Resource.. The Target IRI points to a TimeMap for an Original Resource.
Type
type
Refers to a resource identifying the abstract semantic type of which the link’s context is considered to be an instance.. Refers to a resource identifying the abstract semantic type of which the link’s context is considered to be an instance.
Ugc
ugc
Refers to a resource that is within a context that is User Generated Content. . Refers to a resource that is within a context that is User Generated Content.
Up
up
Refers to a parent document in a hierarchy of documents. . Refers to a parent document in a hierarchy of documents.
VersionHistory
version-history
Points to a resource containing the version history for the context. . Points to a resource containing the version history for the context.
Via
via
Identifies a resource that is the source of the information in the link’s context. . Identifies a resource that is the source of the information in the link’s context.
Webmention
webmention
Identifies a target URI that supports the Webmention protocol. This allows clients that mention a resource in some form of publishing process to contact that endpoint and inform it that this resource has been mentioned.. Identifies a target URI that supports the Webmention protocol. This allows clients that mention a resource in some form of publishing process to contact that endpoint and inform it that this resource has been mentioned.
WorkingCopy
working-copy
Points to a working copy for this resource.. Points to a working copy for this resource.
WorkingCopyOf
working-copy-of
Points to the versioned resource from which this working copy was obtained. . Points to the versioned resource from which this working copy was obtained.