pub enum MedicationStatementStatusCodes {
Draft,
EnteredInError,
Recorded,
}Expand description
MedicationStatementStatusCodes. MedicationStatement Status Codes
FHIR version: 5.0.0.
Variants
Draft
draft
Draft. The medication usage is draft or preliminary.
EnteredInError
entered-in-error
Entered in Error. Some of the actions that are implied by the medication usage may have occurred. For example, the patient may have taken some of the medication. Clinical decision support systems should take this status into account.
Recorded
recorded
Recorded. The action of recording the medication statement is finished.