Enum NameUse Copy item path Source pub enum NameUse {
Anonymous,
Maiden,
Nickname,
Official,
Old,
Temp,
Usual,
}Expand description NameUse . The use of a human name.
FHIR version: 5.0.0.
anonymous
Anonymous. Anonymous assigned name, alias, or pseudonym (used to protect a person’s identity for privacy reasons).
maiden
Name changed for Marriage. A name used prior to changing name because of marriage. This name use is for use by applications that collect and store names that were used prior to a marriage. Marriage naming customs vary greatly around the world, and are constantly changing. This term is not gender specific. The use of this term does not imply any particular history for a person’s name.
nickname
Nickname. A name that is used to address the person in an informal manner, but is not part of their formal or usual name.
official
Official. The formal name as registered in an official (government) registry, but which name might not be commonly used. May be called “legal name”.
old
Old. This name is no longer in use (or was never correct, but retained for records).
temp
Temp. A temporary name. Name.period can provide more detailed information. This may also be used for temporary names assigned at birth or in emergency situations.
usual
Usual. Known as/conventional/the one you normally use.
Converts this type into a shared reference of the (usually inferred) input type.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more Converts to this type from the input type.
Converts to this type from the input type.
The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.