pub enum QuestionnaireAnswerConstraint {
OptionsOnly,
OptionsOrString,
OptionsOrType,
_Custom(String),
}Expand description
QuestionnaireAnswerConstraint. Codes that describe the types of constraints possible on a question item that has a list of permitted answers
FHIR version: 5.0.0.
Variants
OptionsOnly
optionsOnly
Options only. Only values listed as answerOption or in the expansion of the answerValueSet are permitted
OptionsOrString
optionsOrString
Options or string. In addition to the values listed as answerOption or in the expansion of the answerValueSet, free-text strings are permitted. Answers will have a type of ‘string’.
OptionsOrType
optionsOrType
Options or ‘type’. In addition to the values listed as answerOption or in the expansion of the answerValueSet, any other values that correspond to the specified item.type are permitted
_Custom(String)
Custom code value.