pub enum ResearchStudyPhase {
EarlyPhase1,
NA,
Phase1,
Phase1Phase2,
Phase2,
Phase2Phase3,
Phase3,
Phase4,
}Expand description
ResearchStudyPhase. Codes for the stage in the progression of a therapy from initial experimental use in humans in clinical trials to post-market evaluation.
FHIR version: 5.0.0.
Variants
EarlyPhase1
early-phase-1
Early Phase 1. Designation for optional exploratory trials conducted in accordance with the United States Food and Drug Administration’s (FDA) 2006 Guidance on Exploratory Investigational New Drug (IND) Studies. Formerly called Phase 0.
NA
n-a
N/A. Trials without phases (for example, studies of devices or behavioral interventions).
Phase1
phase-1
Phase 1. Includes initial studies to determine the metabolism and pharmacologic actions of drugs in humans, the side effects associated with increasing doses, and to gain early evidence of effectiveness; may include healthy participants and/or patients.
Phase1Phase2
phase-1-phase-2
Phase 1/Phase 2. Trials that are a combination of phases 1 and 2.
Phase2
phase-2
Phase 2. Includes controlled clinical studies conducted to evaluate the effectiveness of the drug for a particular indication or indications in participants with the disease or condition under study and to determine the common short-term side effects and risks.
Phase2Phase3
phase-2-phase-3
Phase 2/Phase 3. Trials that are a combination of phases 2 and 3.
Phase3
phase-3
Phase 3. Includes trials conducted after preliminary evidence suggesting effectiveness of the drug has been obtained, and are intended to gather additional information to evaluate the overall benefit-risk relationship of the drug.
Phase4
phase-4
Phase 4. Studies of FDA-approved drugs to delineate additional information including the drug’s risks, benefits, and optimal use.