pub enum ResearchStudyPrimaryPurposeType {
BasicScience,
DeviceFeasibility,
Diagnostic,
HealthServicesResearch,
Prevention,
Screening,
SupportiveCare,
Treatment,
}Expand description
ResearchStudyPrimaryPurposeType. Codes for the main intent of a research study.
FHIR version: 5.0.0.
Variants
BasicScience
basic-science
Basic Science. One or more interventions for examining the basic mechanism of action (for example, physiology or biomechanics of an intervention).
DeviceFeasibility
device-feasibility
Device Feasibility. An intervention of a device product is being evaluated to determine the feasibility of the product or to test a prototype device and not health outcomes. Such studies are conducted to confirm the design and operating specifications of a device before beginning a full clinical trial.
Diagnostic
diagnostic
Diagnostic. One or more interventions are being evaluated for identifying a disease or health condition.
HealthServicesResearch
health-services-research
Health Services Research. One or more interventions for evaluating the delivery, processes, management, organization, or financing of healthcare.
Prevention
prevention
Prevention. One or more interventions are being assessed for preventing the development of a specific disease or health condition.
Screening
screening
Screening. One or more interventions are assessed or examined for identifying a condition, or risk factors for a condition, in people who are not yet known to have the condition or risk factor.
SupportiveCare
supportive-care
Supportive Care. One or more interventions are evaluated for maximizing comfort, minimizing side effects, or mitigating against a decline in the participant’s health or function.
Treatment
treatment
Treatment. One or more interventions are being evaluated for treating a disease, syndrome, or condition.