pub enum ServiceMode {
Chat,
InPerson,
Telephone,
Videoconference,
}Expand description
ServiceMode. An example set of Service Modes that could be applicable to use to characterize HealthcareServices or PractitionerRoles while searching
FHIR version: 5.0.0.
Variants
Chat
chat
Chat/Messaging. This service will be provided via a realtime chat/messaging conversation
InPerson
in-person
In Person. The service will be provided in person
Telephone
telephone
Telephone. The service will be provided by a teleconferencing facility or regular telephone
Videoconference
videoconference
Video Conference. The service will be provided over a video-conference facility