pub enum SpecimenContainedPreference {
Alternate,
Preferred,
}Expand description
SpecimenContainedPreference. Degree of preference of a type of conditioned specimen.
FHIR version: 5.0.0.
Variants
Alternate
alternate
Alternate. This type of conditioned specimen is an alternate.
Preferred
preferred
Preferred. This type of contained specimen is preferred to collect this kind of specimen.