pub enum StructureMapTargetListMode {
First,
Last,
Share,
Single,
}Expand description
StructureMapTargetListMode. If field is a list, how to manage the production.
FHIR version: 5.0.0.
Variants
First
first
First. when the target list is being assembled, the items for this rule go first. If more than one rule defines a first item (for a given instance of mapping) then this is an error.
Last
last
Last. when the target list is being assembled, the items for this rule go last. If more than one rule defines a last item (for a given instance of mapping) then this is an error.
share
Share. the target instance is shared with the target instances generated by another rule (up to the first common n items, then create new ones).
Single
single
single. the target instance is shared with a number of target instances generated by another rule (up to the first common n items, then create new ones).