pub struct Coding(pub Box<CodingInner>);Expand description
Coding Type: A reference to a code defined by a terminology system.
Coding v5.0.0
A reference to a code defined by a terminology system
A reference to a code defined by a terminology system.
Codes may be defined very casually in enumerations or code lists, up to very formal definitions such as SNOMED CT - see the HL7 v3 Core Principles for more information.
Tuple Fields
0: Box<CodingInner>Implementations